SystemOrganization addCategory: #'Magritte-Tests-Core'!
SystemOrganization addCategory: #'Magritte-Tests-Model'!
SystemOrganization addCategory: #'Magritte-Tests-Description'!
SystemOrganization addCategory: #'Magritte-Tests-Accessor'!
SystemOrganization addCategory: #'Magritte-Tests-Memento'!
SystemOrganization addCategory: #'Magritte-Tests-Condition'!
SystemOrganization addCategory: #'Magritte-Tests-Utility'!
SystemOrganization addCategory: #'Magritte-Tests-Mock'!

TestCase subclass: #MADynamicObjectTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Magritte-Tests-Utility'!

!MADynamicObjectTest methodsFor: 'testing' stamp: 'lr 5/8/2005 20:31'!
testCalculated
	| object dummy |
	object := MADynamicObject on: [ Time millisecondClockValue ].
	dummy := object yourself.
	
	(Delay forMilliseconds: 2) wait.
	self assert: dummy < object.! !

!MADynamicObjectTest methodsFor: 'testing' stamp: 'lr 5/8/2005 20:31'!
testCollection
	| object |
	object := MADynamicObject on: [ OrderedCollection with: 1 with: 2 ].
	self assert: object size = 2.
	self assert: object first = 1.
	self assert: object second = 2.
	
	object add: 3.
	self assert: object size = 2.
	self assert: object first = 1.
	self assert: object second = 2.! !

!MADynamicObjectTest methodsFor: 'testing' stamp: 'lr 5/8/2005 20:31'!
testConstant
	| object |
	object := MADynamicObject on: [ self ].
	self assert: object = self.
	
	object := MADynamicObject on: [ 123 ].
	self assert: object = 123.! !

!MADynamicObjectTest methodsFor: 'testing' stamp: 'lr 11/20/2005 17:48'!
testCopy
	| object first second |
	object := (MADynamicObject on: [ Time millisecondClockValue ])
		copy.
	first := object yourself.
	(Delay forMilliseconds: 2) wait.
	second := object yourself.

	self assert: first < second.! !

!MADynamicObjectTest methodsFor: 'testing' stamp: 'lr 12/21/2005 19:44'!
testCounter
	| object counter |
	counter := nil.
	object := MADynamicObject on: [
		counter := counter isNil
			ifTrue: [ 1 ] 
			ifFalse: [ counter := counter + 1 ] ].

	self assert: object = 1.
	self assert: object yourself = 2.
	self assert: object yourself yourself = 3.! !

!MADynamicObjectTest methodsFor: 'testing' stamp: 'lr 12/21/2005 19:44'!
testDynamic
	| object collection |
	collection := nil.
	object := MADynamicObject on: [
		collection isNil
			ifTrue: [ collection := OrderedCollection with: 1 with: 2 ]
			ifFalse: [ collection ] ].

	self assert: object size = 2.
	self assert: object first = 1.
	self assert: object second = 2.
	
	object add: 3.
	self assert: object size = 3.
	self assert: object first = 1.
	self assert: object second = 2.
	self assert: object third = 3.! !

!MADynamicObjectTest methodsFor: 'testing' stamp: 'lr 12/23/2005 11:43'!
testException
	| object |
	object := MADynamicObject on: [ 1 / 0 ].
	self should: [ object asString ] raise: ZeroDivide.

	object := MADynamicObject on: [ Halt signal ].
	self assert: object asString = 'nil'.! !

!MADynamicObjectTest methodsFor: 'testing' stamp: 'lr 12/23/2005 11:29'!
testNilOrNotNil
	| object |
	object := MADynamicObject on: [ 1 ].
	self deny: object isNil.
	self assert: object notNil.
	
	object := MADynamicObject on: [ nil ].
	self assert: object isNil.
	self deny: object notNil.! !

TestCase subclass: #MAExtensionsTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Magritte-Tests-Core'!

!MAExtensionsTest methodsFor: 'testing-collection' stamp: 'lr 12/6/2005 07:25'!
testCopyWithAll
	| col res |
	col := #( a b ).
	res := col copyWithAll: #( c d ).
	self assert: res = #( a b c d ).
	self deny: col == res.

	col := Set with: #a with: #b.
	res := col copyWithAll: #( c d ).
	self assert: res = (Set with: #a with: #b with: #c with: #d).
	self deny: col == res.! !

!MAExtensionsTest methodsFor: 'testing-collection' stamp: 'lr 12/6/2005 07:27'!
testCopyWithoutFirst
	| col res |
	col := #( a b a c ).
	res := col copyWithoutFirst: #a.
	self assert: res = #( b a c ).
	self deny: col == res.

	col := Set with: #a with: #b with: #c.
	res := col copyWithoutFirst: #a.
	self assert: res = (Set with: #b with: #c).
	self deny: col == res.! !

!MAExtensionsTest methodsFor: 'testing-integer' stamp: 'lr 10/17/2005 08:48'!
testFileSize
	self assert: (1000) asFileSize = '1000 B'.
	self assert: (1024) asFileSize = '1 KB'.

	self assert: (1000 * 1000) asFileSize = '976 KB'.
	self assert: (1024 * 1024) asFileSize = '1 MB'.

	self assert: (1000 * 1000 * 1000) asFileSize = '953 MB'.
	self assert: (1024 * 1024 * 1024) asFileSize = '1 GB'.

	self assert: (1000 * 1000 * 1000 * 1000) asFileSize = '931 GB'.
	self assert: (1024 * 1024 * 1024 * 1024) asFileSize = '1 TB'.

	" etc "! !

!MAExtensionsTest methodsFor: 'testing-string' stamp: 'lr 10/17/2005 08:58'!
testMatches
	self assert: ('' matches: '').
	self assert: ('zort' matches: '').
	self assert: ('zort' matches: 'o').
	self assert: ('zort' matches: 'O').
	self assert: ('zort' matches: '*').
	self assert: ('mobaz' matches: '*baz').
	self deny: ('mobazo' matches: '*baz').
	self assert: ('mobazo' matches: '*baz*').
	self deny: ('mozo' matches: '*baz*').
	self assert: ('foozo' matches: 'foo*').
	self deny: ('bozo' matches: 'foo*').
	self assert: ('foo23baz' matches: 'foo*baz').
	self assert: ('foobaz' matches: 'foo*baz').
	self deny: ('foo23bazo' matches: 'foo*baz').
	self assert: ('Foo' matches: 'foo').
	self deny: ('foobazort' matches: 'foo*baz*zort').
	self assert: ('foobazzort' matches: 'foo*baz*zort').
	self assert: ('afoo3zortthenfoo3zort' matches: '*foo#zort').
	self assert: ('afoodezortorfoo3zort' matches: '*foo*zort').! !

!MAExtensionsTest methodsFor: 'testing-collection' stamp: 'lr 10/17/2005 08:41'!
testMoveDown
	| col |
	col := Array with: 1 with: 2 with: 3.

	self assert: (col moveDown: 1) = 2.
	self assert: col = #( 2 1 3 ).

	self assert: (col moveDown: 1) = 3.
	self assert: col = #( 2 3 1 ).

	self assert: (col moveDown: 1) = 3.
	self assert: col = #( 2 3 1 ).

	self assert: (col moveDown: 0) = 0.
	self assert: col = #( 2 3 1 ).! !

!MAExtensionsTest methodsFor: 'testing-collection' stamp: 'lr 10/17/2005 08:42'!
testMoveUp
	| col |
	col := Array with: 1 with: 2 with: 3.

	self assert: (col moveUp: 3) = 2.
	self assert: col = #( 1 3 2 ).

	self assert: (col moveUp: 3) = 1.
	self assert: col = #( 3 1 2 ).

	self assert: (col moveUp: 3) = 1.
	self assert: col = #( 3 1 2 ).

	self assert: (col moveUp: 0) = 0.
	self assert: col = #( 3 1 2 ).! !

!MAExtensionsTest methodsFor: 'testing-collection' stamp: 'lr 1/3/2006 11:39'!
testReduce
	self assert: ((1 to: 9) reduce: [ :a :b | a ]) = 1.
	self assert: ((1 to: 9) reduce: [ :a :b | b ]) = 9.

	self assert: ((1 to: 9) reduce: #+) = 45.
	self assert: ((1 to: 9) reduce: [ :a :b | a + b ]) = 45.

	self assert: ((1 to: 9) reduce: #*) = 362880.
	self assert: ((1 to: 9) reduce: [ :a :b | a * b ]) = 362880.

	self assert: (#('a' 'b' 'c') reduce: #,) = 'abc'.
	self assert: (#('a' 'b' 'c') reduce: [ :a :b | a , ' ' , b ]) = 'a b c'.
	self assert: (#('a' 'b' 'c') reduce: [ :a :b | b , ' ' , a ]) = 'c b a'.! !

!MAExtensionsTest methodsFor: 'testing-symbol' stamp: 'lr 1/1/2006 10:55'!
testValue
	self assert: (#yourself value: 'abc') = 'abc'.
	self assert: (#reverse value: 'abc') = 'cba'.
! !

!MAExtensionsTest methodsFor: 'testing-symbol' stamp: 'lr 1/1/2006 10:59'!
testValueValue
	self assert: (#+ value: 4 value: 2) = 6.
	self assert: (#/ value: 4 value: 2) = 2.! !

TestCase subclass: #MAFileModelTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Magritte-Tests-Model'!

!MAFileModelTest methodsFor: 'testing' stamp: 'lr 9/9/2005 11:19'!
testContents
	| model |
	model := MAFileModel new.
	self assert: model contents isEmpty.
	
	model contents: 'hello'.
	self assert: model contents = 'hello'.
	self assert: model size = 5.! !

!MAFileModelTest methodsFor: 'testing' stamp: 'lr 8/10/2005 19:58'!
testFilename
	| model |
	model := MAFileModel new.
	self assert: model filename isEmpty.
	self assert: model extension isEmpty.
	
	model filename: 'test.txt'.
	self assert: model filename = 'test.txt'.
	self assert: model extension = 'txt'.! !

!MAFileModelTest methodsFor: 'testing' stamp: 'lr 9/9/2005 11:16'!
testIsEmpty
	| model |
	model := MAFileModel new.
	self assert: model isEmpty.
	
	model filename: 'foo.txt'.
	self assert: model isEmpty.
	
	model mimetype: 'text/plain'.
	self assert: model isEmpty.
	
	model contents: 'hello'.
	self deny: model isEmpty.! !

!MAFileModelTest methodsFor: 'testing' stamp: 'lr 9/9/2005 11:18'!
testMimetype
	| model |
	model := MAFileModel new.
	self assert: model mimetype = 'application/octet-stream'.
	self assert: model maintype = 'application'.
	
	model filename: 'test.txt'.
	self assert: model mimetype = 'text/plain'.
	self assert: model maintype = 'text'.
	
	model mimetype: 'text/html'.
	self assert: model mimetype = 'text/html'.
	self assert: model maintype = 'text'.! !

!MAFileModelTest methodsFor: 'testing' stamp: 'lr 9/9/2005 11:15'!
testMimetypeApplication
	| model |
	model := MAFileModel new
		mimetype: 'application/pdf';
		yourself.

	self assert: model isApplication.
	self deny: model isAudio.
	self deny: model isImage.
	self deny: model isText.
	self deny: model isVideo.	! !

!MAFileModelTest methodsFor: 'testing' stamp: 'lr 9/9/2005 11:15'!
testMimetypeAudio
	| model |
	model := MAFileModel new
		mimetype: 'audio/mpeg';
		yourself.

	self deny: model isApplication.
	self assert: model isAudio.
	self deny: model isImage.
	self deny: model isText.
	self deny: model isVideo.! !

!MAFileModelTest methodsFor: 'testing' stamp: 'lr 9/9/2005 11:15'!
testMimetypeDefault
	| model |
	model := MAFileModel new.

	self assert: model isApplication.
	self deny: model isAudio.
	self deny: model isImage.
	self deny: model isText.
	self deny: model isVideo.! !

!MAFileModelTest methodsFor: 'testing' stamp: 'lr 9/9/2005 11:15'!
testMimetypeImage
	| model |
	model := MAFileModel new
		mimetype: 'image/png';
		yourself.

	self deny: model isApplication.
	self deny: model isAudio.
	self assert: model isImage.
	self deny: model isText.
	self deny: model isVideo.! !

!MAFileModelTest methodsFor: 'testing' stamp: 'lr 9/9/2005 11:15'!
testMimetypeText
	| model |
	model := MAFileModel new
		mimetype: 'text/xml';
		yourself.

	self deny: model isApplication.
	self deny: model isAudio.
	self deny: model isImage.
	self assert: model isText.
	self deny: model isVideo.! !

!MAFileModelTest methodsFor: 'testing' stamp: 'lr 9/9/2005 11:15'!
testMimetypeVideo
	| model |
	model := MAFileModel new
		mimetype: 'video/mpeg';
		yourself.

	self deny: model isApplication.
	self deny: model isAudio.
	self deny: model isImage.
	self deny: model isText.
	self assert: model isVideo.! !

TestCase subclass: #MAObjectTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Magritte-Tests-Core'!

MAObjectTest subclass: #MAAccessorTest
	instanceVariableNames: 'accessor value'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Magritte-Tests-Accessor'!

!MAAccessorTest class methodsFor: 'testing' stamp: 'lr 12/5/2005 20:58'!
isAbstract
	^ true! !

!MAAccessorTest methodsFor: 'accessing' stamp: 'lr 5/8/2005 20:29'!
accessor
	^ accessor! !

!MAAccessorTest methodsFor: 'private' stamp: 'lr 5/8/2005 20:29'!
accessorInstance
	self subclassResponsibility.! !

!MAAccessorTest methodsFor: 'private' stamp: 'lr 12/5/2005 20:58'!
actualClass
	^ MAAccessor! !

!MAAccessorTest methodsFor: 'accessing' stamp: 'lr 5/8/2005 20:29'!
instance
	^ accessor! !

!MAAccessorTest methodsFor: 'running' stamp: 'lr 5/8/2005 20:29'!
setUp
	super setUp.
	accessor := self accessorInstance.! !

!MAAccessorTest methodsFor: 'testing-testing' stamp: 'lr 5/8/2005 20:29'!
testCanRead
	self subclassResponsibility.! !

!MAAccessorTest methodsFor: 'testing-testing' stamp: 'lr 5/8/2005 20:29'!
testCanWrite
	self subclassResponsibility.! !

!MAAccessorTest methodsFor: 'testing-testing' stamp: 'lr 12/16/2005 18:30'!
testIsAccessor
	self assert: self instance isAccessor.! !

!MAAccessorTest methodsFor: 'testing' stamp: 'lr 1/18/2006 10:43'!
testRead
	self subclassResponsibility.! !

!MAAccessorTest methodsFor: 'testing-identity' stamp: 'lr 1/4/2006 13:08'!
testStore
	self assert: (self actualClass evaluatorClass 
		evaluate: self accessor storeString) 
			= self accessor.! !

!MAAccessorTest methodsFor: 'testing' stamp: 'lr 1/18/2006 10:43'!
testWrite
	self subclassResponsibility.! !

!MAAccessorTest methodsFor: 'accessing-model' stamp: 'lr 5/8/2005 20:29'!
value
	^ value! !

!MAAccessorTest methodsFor: 'accessing-model' stamp: 'lr 5/8/2005 20:29'!
value: anObject
	value := anObject! !

MAAccessorTest subclass: #MABlockAccessorTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Magritte-Tests-Accessor'!

!MABlockAccessorTest class methodsFor: 'testing' stamp: 'lr 12/5/2005 20:58'!
isAbstract
	^ false! !

!MABlockAccessorTest methodsFor: 'private' stamp: 'lr 12/21/2005 20:24'!
accessorInstance
	^ self actualClass 
		read: [ :model | model value ]
		write: [ :model :object | model value: object ].! !

!MABlockAccessorTest methodsFor: 'private' stamp: 'lr 12/5/2005 20:58'!
actualClass
	^ MABlockAccessor! !

!MABlockAccessorTest methodsFor: 'testing-testing' stamp: 'lr 12/16/2005 16:56'!
testCanRead
	self assert: (self instance canRead: self).
	self instance readBlock: nil.
	self deny: (self instance canRead: self).! !

!MABlockAccessorTest methodsFor: 'testing-testing' stamp: 'lr 12/16/2005 16:54'!
testCanWrite
	self assert: (self instance canWrite: nil).
	self assert: (self instance canWrite: 123).
	self assert: (self instance canWrite: self).

	self instance writeBlock: nil.	
	self deny: (self instance canWrite: nil).
	self deny: (self instance canWrite: 123).
	self deny: (self instance canWrite: self).
! !

!MABlockAccessorTest methodsFor: 'testing' stamp: 'lr 5/8/2005 20:29'!
testRead
	self value: 123.
	self assert: (self accessor read: self) = 123.
	
	self value: '12'.
	self assert: (self accessor read: self) = '12'.! !

!MABlockAccessorTest methodsFor: 'testing' stamp: 'lr 5/8/2005 20:29'!
testReadBlock
	self accessor readBlock: [ :model |
		self assert: model = self. 123 ].
	self assert: (self accessor read: self) = 123.! !

!MABlockAccessorTest methodsFor: 'testing-identity' stamp: 'lr 5/8/2005 20:29'!
testReferenceStream
	"The class BlockContext is not serializeable, ignore this test."! !

!MABlockAccessorTest methodsFor: 'testing-identity' stamp: 'lr 1/4/2006 13:16'!
testStore
	"The class BlockContext is not serializeable, ignore this test."! !

!MABlockAccessorTest methodsFor: 'testing' stamp: 'lr 5/8/2005 20:29'!
testWrite
	self accessor write: 123 to: self.
	self assert: self value = 123.
	
	self accessor write: '123' to: self.
	self assert: self value = '123'.! !

!MABlockAccessorTest methodsFor: 'testing' stamp: 'lr 5/8/2005 20:29'!
testWriteBlock
	self accessor writeBlock: [ :model :object |
		self assert: model = self.
		self assert: object = 123 ].
	self accessor write: 123 to: self.! !

MAAccessorTest subclass: #MACascadeAccessorTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Magritte-Tests-Accessor'!

!MACascadeAccessorTest class methodsFor: 'testing' stamp: 'lr 12/5/2005 20:58'!
isAbstract
	^ false! !

!MACascadeAccessorTest methodsFor: 'private' stamp: 'lr 12/21/2005 20:23'!
accessorInstance
	^ self actualClass selectors: #( holder contents value ).! !

!MACascadeAccessorTest methodsFor: 'private' stamp: 'lr 12/5/2005 20:58'!
actualClass
	^ MACascadeAccessor! !

!MACascadeAccessorTest methodsFor: 'private' stamp: 'lr 5/8/2005 20:29'!
holder
	^ ValueHolder new 
		contents: self;
		yourself.! !

!MACascadeAccessorTest methodsFor: 'testing' stamp: 'lr 10/3/2005 23:17'!
testAccessor
	self accessor accessor: self.
	self assert: self accessor accessor = self.! !

!MACascadeAccessorTest methodsFor: 'testing-testing' stamp: 'lr 12/16/2005 16:56'!
testCanRead
	self assert: (self accessor canRead: self).
	self accessor next next readSelector: #zork.
	self deny: (self accessor canRead: self).! !

!MACascadeAccessorTest methodsFor: 'testing-testing' stamp: 'lr 12/16/2005 16:56'!
testCanWrite
	self assert: (self accessor canWrite: self).
	self accessor next next writeSelector: #zork.
	self deny: (self accessor canWrite: self).! !

!MACascadeAccessorTest methodsFor: 'testing' stamp: 'lr 12/16/2005 16:55'!
testKind
	self assert: (self accessor class = MACascadeAccessor).
	self assert: (self accessor accessor class = MASelectorAccessor).
	self assert: (self accessor next class = MACascadeAccessor).
	self assert: (self accessor next accessor class = MASelectorAccessor).
	self assert: (self accessor next next class = MASelectorAccessor).! !

!MACascadeAccessorTest methodsFor: 'testing' stamp: 'lr 10/3/2005 23:17'!
testNext
	self accessor next: self.
	self assert: self accessor next = self.! !

!MACascadeAccessorTest methodsFor: 'testing' stamp: 'lr 5/8/2005 20:29'!
testRead
	self value: 123.
	self assert: (self accessor read: self) = 123.
	
	self value: '12'.
	self assert: (self accessor read: self) = '12'.! !

!MACascadeAccessorTest methodsFor: 'testing' stamp: 'lr 5/8/2005 20:29'!
testSelector
	self assert: self accessor accessor selector = #holder.
	self assert: self accessor next accessor selector = #contents.
	self assert: self accessor next next selector = #value.! !

!MACascadeAccessorTest methodsFor: 'testing' stamp: 'lr 5/8/2005 20:29'!
testWrite
	self accessor write: 123 to: self.
	self assert: self value = 123.
	
	self accessor write: '123' to: self.
	self assert: self value = '123'.! !

MAAccessorTest subclass: #MAContainerAccessorTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Magritte-Tests-Accessor'!

!MAContainerAccessorTest class methodsFor: 'testing' stamp: 'lr 12/5/2005 20:58'!
isAbstract
	^ false! !

!MAContainerAccessorTest methodsFor: 'private' stamp: 'lr 12/21/2005 20:23'!
accessorInstance
	^ self actualClass new.! !

!MAContainerAccessorTest methodsFor: 'private' stamp: 'lr 12/5/2005 20:58'!
actualClass
	^ MAContainerAccessor! !

!MAContainerAccessorTest methodsFor: 'testing-testing' stamp: 'lr 12/16/2005 16:57'!
testCanRead
	self assert: (self accessor canRead: self).! !

!MAContainerAccessorTest methodsFor: 'testing-testing' stamp: 'lr 12/16/2005 16:57'!
testCanWrite
	self deny: (self accessor canWrite: self).! !

!MAContainerAccessorTest methodsFor: 'testing' stamp: 'lr 5/8/2005 20:30'!
testRead
	self assert: (self accessor read: 123) = 123.! !

!MAContainerAccessorTest methodsFor: 'testing' stamp: 'lr 5/8/2005 20:30'!
testWrite
	self 	
		should: [ self accessor write: 123 to: self ] 
		raise: Error.
	self assert: self value isNil.! !

MAAccessorTest subclass: #MADictionaryAccessorTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Magritte-Tests-Accessor'!

!MADictionaryAccessorTest class methodsFor: 'testing' stamp: 'lr 12/5/2005 20:58'!
isAbstract
	^ false! !

!MADictionaryAccessorTest methodsFor: 'private' stamp: 'lr 12/21/2005 20:23'!
accessorInstance
	^ self actualClass key: #value.! !

!MADictionaryAccessorTest methodsFor: 'private' stamp: 'lr 12/5/2005 20:58'!
actualClass
	^ MADictionaryAccessor! !

!MADictionaryAccessorTest methodsFor: 'accessing' stamp: 'lr 1/4/2006 13:12'!
at: aKey
	self assert: aKey = #value.
	^ value! !

!MADictionaryAccessorTest methodsFor: 'accessing' stamp: 'lr 1/4/2006 13:12'!
at: aKey put: aValue
	self assert: aKey = #value.
	^ value := aValue.! !

!MADictionaryAccessorTest methodsFor: 'accessing' stamp: 'lr 12/16/2005 16:57'!
includesKey: aKey
	^ aKey = #value.! !

!MADictionaryAccessorTest methodsFor: 'testing-testing' stamp: 'lr 12/16/2005 16:58'!
testCanRead
	self assert: (self accessor canRead: self).
	self accessor key: #zork.
	self deny: (self accessor canRead: self).
! !

!MADictionaryAccessorTest methodsFor: 'testing-testing' stamp: 'lr 12/16/2005 16:58'!
testCanWrite
	self assert: (self accessor canWrite: self).
! !

!MADictionaryAccessorTest methodsFor: 'testing' stamp: 'lr 10/3/2005 23:16'!
testKey
	self accessor key: #other.
	self assert: self accessor key = #other.! !

!MADictionaryAccessorTest methodsFor: 'testing' stamp: 'lr 12/16/2005 17:02'!
testRead
	self value: 123.
	self assert: (self accessor read: self) = 123.
	
	self value: '12'.
	self assert: (self accessor read: self) = '12'.! !

!MADictionaryAccessorTest methodsFor: 'testing' stamp: 'lr 10/3/2005 23:11'!
testWrite
	self accessor write: 123 to: self.
	self assert: self value = 123.
	
	self accessor write: '123' to: self.
	self assert: self value = '123'.! !

MAAccessorTest subclass: #MANullAccessorTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Magritte-Tests-Accessor'!

!MANullAccessorTest class methodsFor: 'testing' stamp: 'lr 12/5/2005 20:58'!
isAbstract
	^ false! !

!MANullAccessorTest methodsFor: 'private' stamp: 'lr 12/21/2005 20:23'!
accessorInstance
	^ self actualClass new.! !

!MANullAccessorTest methodsFor: 'private' stamp: 'lr 12/5/2005 20:58'!
actualClass
	^ MANullAccessor! !

!MANullAccessorTest methodsFor: 'testing-testing' stamp: 'lr 12/16/2005 17:02'!
testCanRead
	self deny: (self accessor canRead: self).! !

!MANullAccessorTest methodsFor: 'testing-testing' stamp: 'lr 12/16/2005 17:02'!
testCanWrite
	self deny: (self accessor canWrite: nil).! !

!MANullAccessorTest methodsFor: 'testing' stamp: 'lr 5/8/2005 20:31'!
testRead
	self 
		should: [ self accessor read: self ]
		raise: Error.! !

!MANullAccessorTest methodsFor: 'testing' stamp: 'lr 5/8/2005 20:31'!
testWrite
	self 	
		should: [ self accessor write: 123 to: self ] 
		raise: Error.
	self assert: self value isNil.! !

MAAccessorTest subclass: #MASelectorAccessorTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Magritte-Tests-Accessor'!

MASelectorAccessorTest subclass: #MAAutoSelectorAccessorTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Magritte-Tests-Accessor'!

!MAAutoSelectorAccessorTest class methodsFor: 'testing' stamp: 'lr 12/5/2005 20:58'!
isAbstract
	^ false! !

!MAAutoSelectorAccessorTest methodsFor: 'private' stamp: 'lr 12/5/2005 20:58'!
actualClass
	^ MAAutoSelectorAccessor! !

!MAAutoSelectorAccessorTest methodsFor: 'running' stamp: 'lr 11/14/2005 21:48'!
tearDown
	super tearDown.
	
	" remove methods and category "
	(self class organization listAtCategoryNamed: self accessor categoryName)
		do: [ :each | self class removeSelector: each ].
	self class organization removeCategory: self accessor categoryName.

	" remove instance variables "
	self class instVarNames 
		do: [ :each | self class removeInstVarName: each ].
	
	! !

!MAAutoSelectorAccessorTest methodsFor: 'testing' stamp: 'lr 12/16/2005 17:08'!
testReadFirst
	self accessor selector: #foo.
	self assert: (self accessor read: self) isNil.
	self accessor write: 123 to: self.
	self assert: (self accessor read: self) = 123.! !

!MAAutoSelectorAccessorTest methodsFor: 'testing' stamp: 'lr 12/16/2005 17:09'!
testWriteFirst
	self accessor selector: #foo.
	self accessor write: 123 to: self.
	self assert: (self accessor read: self) = 123.! !

!MASelectorAccessorTest class methodsFor: 'testing' stamp: 'lr 12/5/2005 20:58'!
isAbstract
	^ false! !

!MASelectorAccessorTest methodsFor: 'private' stamp: 'lr 12/21/2005 20:24'!
accessorInstance
	^ self actualClass selector: #value.! !

!MASelectorAccessorTest methodsFor: 'private' stamp: 'lr 12/5/2005 20:58'!
actualClass
	^ MASelectorAccessor! !

!MASelectorAccessorTest methodsFor: 'testing-testing' stamp: 'lr 12/16/2005 17:03'!
testCanRead
	self assert: (self accessor canRead: self).

	self accessor readSelector: #zork.
	self deny: (self accessor canRead: self).

	self accessor readSelector: nil.
	self deny: (self accessor canRead: self).! !

!MASelectorAccessorTest methodsFor: 'testing-testing' stamp: 'lr 12/16/2005 17:04'!
testCanWrite
	self assert: (self accessor canWrite: self).

	self accessor writeSelector: #zork:.
	self deny: (self accessor canWrite: self).

	self accessor writeSelector: nil.
	self deny: (self accessor canWrite: self).! !

!MASelectorAccessorTest methodsFor: 'testing' stamp: 'lr 5/8/2005 20:32'!
testRead
	self value: 123.
	self assert: (self accessor read: self) = 123.
	
	self value: '12'.
	self assert: (self accessor read: self) = '12'.! !

!MASelectorAccessorTest methodsFor: 'testing' stamp: 'lr 5/8/2005 20:32'!
testReadSelector
	self accessor readSelector: #contents.
	
	self assert: self accessor selector = #contents.
	self assert: self accessor readSelector = #contents.
	self assert: self accessor writeSelector = #value:.! !

!MASelectorAccessorTest methodsFor: 'testing' stamp: 'lr 5/8/2005 20:32'!
testSelector
	self accessor selector: #contents.
	
	self assert: self accessor selector = #contents.
	self assert: self accessor readSelector = #contents.
	self assert: self accessor writeSelector = #contents:.! !

!MASelectorAccessorTest methodsFor: 'testing' stamp: 'lr 5/8/2005 20:32'!
testWrite
	self accessor write: 123 to: self.
	self assert: self value = 123.
	
	self accessor write: '123' to: self.
	self assert: self value = '123'.! !

!MASelectorAccessorTest methodsFor: 'testing' stamp: 'lr 5/8/2005 20:32'!
testWriteSelector
	self accessor writeSelector: #contents:.
	
	self assert: self accessor selector = #value.
	self assert: self accessor readSelector = #value.
	self assert: self accessor writeSelector = #contents:.! !

MAAccessorTest subclass: #MAVariableAccessorTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Magritte-Tests-Accessor'!

!MAVariableAccessorTest class methodsFor: 'testing' stamp: 'lr 12/5/2005 20:58'!
isAbstract
	^ false! !

!MAVariableAccessorTest methodsFor: 'private' stamp: 'lr 12/21/2005 20:24'!
accessorInstance
	^ self actualClass name: 'value'.! !

!MAVariableAccessorTest methodsFor: 'private' stamp: 'lr 12/5/2005 20:58'!
actualClass
	^ MAVariableAccessor! !

!MAVariableAccessorTest methodsFor: 'testing-testing' stamp: 'lr 12/16/2005 17:04'!
testCanRead
	self assert: (self accessor canRead: self).

	self accessor name: 'zork'.
	self deny: (self accessor canRead: self).
! !

!MAVariableAccessorTest methodsFor: 'testing-testing' stamp: 'lr 12/16/2005 17:04'!
testCanWrite
	self assert: (self accessor canWrite: self).

	self accessor name: 'zork'.
	self deny: (self accessor canWrite: self).
! !

!MAVariableAccessorTest methodsFor: 'testing' stamp: 'lr 10/3/2005 23:15'!
testName
	self accessor name: 'other'.
	self assert: self accessor name = 'other'.! !

!MAVariableAccessorTest methodsFor: 'testing' stamp: 'lr 5/9/2005 13:48'!
testRead
	self value: 123.
	self assert: (self accessor read: self) = 123.
	
	self value: '12'.
	self assert: (self accessor read: self) = '12'.! !

!MAVariableAccessorTest methodsFor: 'testing' stamp: 'lr 5/9/2005 13:49'!
testWrite
	self accessor write: 123 to: self.
	self assert: self value = 123.
	
	self accessor write: '123' to: self.
	self assert: self value = '123'.! !

MAObjectTest subclass: #MAConditionTest
	instanceVariableNames: 'condition'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Magritte-Tests-Condition'!

MAConditionTest subclass: #MAComposedConditionTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Magritte-Tests-Condition'!

MAComposedConditionTest subclass: #MAAllConditionTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Magritte-Tests-Condition'!

!MAAllConditionTest class methodsFor: 'testing' stamp: 'lr 12/5/2005 20:58'!
isAbstract
	^ false! !

!MAAllConditionTest methodsFor: 'private' stamp: 'lr 1/18/2006 08:58'!
actualClass
	^ MAAllCondition! !

!MAAllConditionTest methodsFor: 'testing' stamp: 'lr 1/18/2006 09:29'!
testAll
	self assert: (self condition & self true) class = MAAllCondition.
	self assert: (self condition & self false) conditions first = self false.! !

!MAAllConditionTest methodsFor: 'testing' stamp: 'lr 10/3/2005 08:35'!
testBinary
	self satisfies: self true & self true.
	self fails: self true & self false.
	self fails: self false & self true.
	self fails: self false & self false.! !

!MAAllConditionTest methodsFor: 'testing' stamp: 'lr 1/18/2006 09:20'!
testEmpty
	self satisfies: self condition.! !

!MAAllConditionTest methodsFor: 'testing' stamp: 'lr 1/16/2006 09:47'!
testParsing
	self satisfies: (self parse: 'true & true').
	self fails: (self parse: 'false & true').
	self fails: (self parse: 'true & false').
	self fails: (self parse: 'false & false').

	self satisfies: (self parse: 'true & true & true').
	self fails: (self parse: 'true & true & false').
	self fails: (self parse: 'true & false & true').
	self fails: (self parse: 'false & true & false').
	self fails: (self parse: 'false & true & true').
	self fails: (self parse: 'false & false & false').! !

!MAAllConditionTest methodsFor: 'testing' stamp: 'lr 1/18/2006 09:20'!
testUnary
	self satisfies: self condition & self true.
	self fails: self condition & self false.! !

MAComposedConditionTest subclass: #MAAnyConditionTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Magritte-Tests-Condition'!

!MAAnyConditionTest class methodsFor: 'testing' stamp: 'lr 12/5/2005 20:58'!
isAbstract
	^ false! !

!MAAnyConditionTest methodsFor: 'private' stamp: 'lr 1/18/2006 08:59'!
actualClass
	^ MAAnyCondition! !

!MAAnyConditionTest methodsFor: 'testing' stamp: 'lr 1/18/2006 09:29'!
testAny
	self assert: (self condition | self true) class = MAAnyCondition.
	self assert: (self condition | self false) conditions first = self false.! !

!MAAnyConditionTest methodsFor: 'testing' stamp: 'lr 10/3/2005 08:36'!
testBinary
	self satisfies: self true | self true.
	self satisfies: self true | self false.
	self satisfies: self false | self true.
	self fails: self false | self false.! !

!MAAnyConditionTest methodsFor: 'testing' stamp: 'lr 1/18/2006 09:20'!
testEmpty
	self fails: self condition.! !

!MAAnyConditionTest methodsFor: 'testing' stamp: 'lr 1/16/2006 09:48'!
testParsing
	self satisfies: (self parse: 'true | true').
	self satisfies: (self parse: 'false | true').
	self satisfies: (self parse: 'true | false').
	self fails: (self parse: 'false | false').

	self satisfies: (self parse: 'true | true | true').
	self satisfies: (self parse: 'true | true | false').
	self satisfies: (self parse: 'true | false | true').
	self satisfies: (self parse: 'false | true | false').
	self satisfies: (self parse: 'false | true | true').
	self fails: (self parse: 'false | false | false').! !

!MAAnyConditionTest methodsFor: 'testing' stamp: 'lr 1/18/2006 09:20'!
testUnary
	self satisfies: self condition | self true.
	self fails: self condition | self false.! !

!MAComposedConditionTest class methodsFor: 'testing' stamp: 'lr 12/5/2005 20:58'!
isAbstract
	^ true! !

!MAComposedConditionTest methodsFor: 'private' stamp: 'lr 1/18/2006 08:58'!
actualClass
	^ MAComposedCondition! !

!MAComposedConditionTest methodsFor: 'testing' stamp: 'lr 1/18/2006 09:20'!
testIsComposed
	self assert: self condition isComposed.! !

MAComposedConditionTest subclass: #MANoneConditionTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Magritte-Tests-Condition'!

!MANoneConditionTest class methodsFor: 'testing' stamp: 'lr 12/5/2005 20:58'!
isAbstract
	^ false! !

!MANoneConditionTest methodsFor: 'private' stamp: 'lr 1/18/2006 08:59'!
actualClass
	^ MANoneCondition! !

!MANoneConditionTest methodsFor: 'testing' stamp: 'lr 10/3/2005 08:37'!
testBinary
	self fails: self true !! self true.
	self fails: self true !! self false.
	self fails: self false !! self true.
	self satisfies: self false !! self false.! !

!MANoneConditionTest methodsFor: 'testing' stamp: 'lr 1/18/2006 09:22'!
testEmpty
	self satisfies: self condition.! !

!MANoneConditionTest methodsFor: 'testing' stamp: 'lr 1/18/2006 09:30'!
testNone
	self assert: (self condition !! self true) class = MANoneCondition.
	self assert: (self condition !! self false) conditions first = self false.! !

!MANoneConditionTest methodsFor: 'testing' stamp: 'lr 1/16/2006 09:50'!
testParsing
	self fails: (self parse: 'true not').
	self satisfies: (self parse: 'false not').

	self satisfies: (self parse: 'true not not').
	self fails: (self parse: 'false not not').

	self fails: (self parse: 'true not & true not').
	self fails: (self parse: 'false not & true not').
	self fails: (self parse: 'true not & false not').
	self satisfies: (self parse: 'false not & false not').

	self fails: (self parse: 'true not & true not & true not').
	self fails: (self parse: 'true not & true not & false not').
	self fails: (self parse: 'true not & false not & true not').
	self fails: (self parse: 'false not & true not & false not').
	self fails: (self parse: 'false not & true not & true not').
	self satisfies: (self parse: 'false not & false not & false not').! !

!MANoneConditionTest methodsFor: 'testing' stamp: 'lr 1/18/2006 09:22'!
testUnary
	self fails: self condition !! self true.
	self satisfies: self condition !! self false.! !

!MAConditionTest class methodsFor: 'testing' stamp: 'lr 12/5/2005 20:58'!
isAbstract
	^ true! !

!MAConditionTest methodsFor: 'private' stamp: 'lr 1/18/2006 08:58'!
actualClass
	^ MACondition! !

!MAConditionTest methodsFor: 'accessing' stamp: 'lr 1/18/2006 09:14'!
condition
	^ condition! !

!MAConditionTest methodsFor: 'private' stamp: 'lr 1/18/2006 09:16'!
conditionInstance
	^ self actualClass new.! !

!MAConditionTest methodsFor: 'utilities' stamp: 'lr 1/18/2006 09:16'!
fails: aCondition
	self deny: (aCondition value: self).! !

!MAConditionTest methodsFor: 'constants' stamp: 'lr 1/18/2006 09:00'!
false
	^ MAFalseCondition new.! !

!MAConditionTest methodsFor: 'accessing' stamp: 'lr 1/18/2006 09:35'!
instance
	^ condition! !

!MAConditionTest methodsFor: 'utilities' stamp: 'lr 1/18/2006 09:16'!
parse: aString
	^ MAConditionParser parse: aString.! !

!MAConditionTest methodsFor: 'private' stamp: 'lr 11/21/2005 20:31'!
queryString
	^ 'foo bar'! !

!MAConditionTest methodsFor: 'utilities' stamp: 'lr 1/18/2006 09:16'!
satisfies: aCondition
	self assert: (aCondition value: self).! !

!MAConditionTest methodsFor: 'running' stamp: 'lr 1/18/2006 09:15'!
setUp
	super setUp.
	condition := self conditionInstance.! !

!MAConditionTest methodsFor: 'testing' stamp: 'lr 1/18/2006 09:30'!
testAll
	self assert: (self condition & self true) class = MAAllCondition.
	self assert: (self condition & self false) conditions first = self condition.
	self assert: (self condition & self false) conditions second = self false.! !

!MAConditionTest methodsFor: 'testing' stamp: 'lr 1/18/2006 09:30'!
testAny
	self assert: (self condition | self true) class = MAAnyCondition.
	self assert: (self condition | self false) conditions first = self condition.
	self assert: (self condition | self false) conditions second = self false.! !

!MAConditionTest methodsFor: 'testing-testing' stamp: 'lr 1/18/2006 09:20'!
testIsComposed
	self deny: self condition isComposed.! !

!MAConditionTest methodsFor: 'testing-testing' stamp: 'lr 1/18/2006 09:39'!
testIsCondition
	self assert: self instance isCondition.! !

!MAConditionTest methodsFor: 'testing-testing' stamp: 'lr 1/18/2006 09:21'!
testIsConstant
	self deny: self condition isConstant.! !

!MAConditionTest methodsFor: 'testing' stamp: 'lr 1/18/2006 09:30'!
testNone
	self assert: (self condition !! self true) class = MANoneCondition.
	self assert: (self condition !! self false) conditions first = self condition.
	self assert: (self condition !! self false) conditions second = self false.! !

!MAConditionTest methodsFor: 'testing' stamp: 'lr 1/18/2006 09:30'!
testNot
	self assert: self condition not class = MANoneCondition.
	self assert: self condition not conditions first = self condition.! !

!MAConditionTest methodsFor: 'constants' stamp: 'lr 1/18/2006 09:01'!
true
	^ MATrueCondition new.! !

MAConditionTest subclass: #MAConstantConditionTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Magritte-Tests-Condition'!

!MAConstantConditionTest class methodsFor: 'testing' stamp: 'lr 12/5/2005 20:58'!
isAbstract
	^ true! !

!MAConstantConditionTest methodsFor: 'private' stamp: 'lr 1/18/2006 09:00'!
actualClass
	^ MAConstantCondition! !

!MAConstantConditionTest methodsFor: 'testing' stamp: 'lr 1/18/2006 09:21'!
testIsConstant
	self assert: self condition isConstant.! !

MAConstantConditionTest subclass: #MAFalseConditionTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Magritte-Tests-Condition'!

!MAFalseConditionTest class methodsFor: 'testing' stamp: 'lr 12/5/2005 20:58'!
isAbstract
	^ false! !

!MAFalseConditionTest methodsFor: 'private' stamp: 'lr 1/18/2006 09:00'!
actualClass
	^ MAFalseCondition! !

!MAFalseConditionTest methodsFor: 'testing-operators' stamp: 'lr 1/18/2006 09:21'!
testAll
	self assert: (self condition & self true) = self false.
	self assert: (self condition & self false) = self false.! !

!MAFalseConditionTest methodsFor: 'testing-operators' stamp: 'lr 1/18/2006 09:21'!
testAny
	self assert: (self condition | self true) = self true.
	self assert: (self condition | self false) = self false.! !

!MAFalseConditionTest methodsFor: 'testing' stamp: 'lr 1/18/2006 09:21'!
testFalse
	self fails: self condition.! !

!MAFalseConditionTest methodsFor: 'testing-operators' stamp: 'lr 1/18/2006 09:22'!
testNot
	self assert: self condition not = self true.! !

!MAFalseConditionTest methodsFor: 'testing' stamp: 'lr 1/16/2006 09:36'!
testParsing
	self fails: (self parse: 'false').
	self satisfies: (self parse: 'false not').! !

MAConstantConditionTest subclass: #MATrueConditionTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Magritte-Tests-Condition'!

!MATrueConditionTest class methodsFor: 'testing' stamp: 'lr 12/5/2005 20:58'!
isAbstract
	^ false! !

!MATrueConditionTest methodsFor: 'private' stamp: 'lr 1/18/2006 09:01'!
actualClass
	^ MATrueCondition! !

!MATrueConditionTest methodsFor: 'testing-operators' stamp: 'lr 1/18/2006 09:22'!
testAll
	self assert: (self condition & self true) = self true.
	self assert: (self condition & self false) = self false.! !

!MATrueConditionTest methodsFor: 'testing-operators' stamp: 'lr 1/18/2006 09:22'!
testAny
	self assert: (self condition | self true) = self true.
	self assert: (self condition | self false) = self true.! !

!MATrueConditionTest methodsFor: 'testing-operators' stamp: 'lr 1/18/2006 09:22'!
testNot
	self assert: self condition not = self false.! !

!MATrueConditionTest methodsFor: 'testing' stamp: 'lr 1/16/2006 09:36'!
testParsing
	self satisfies: (self parse: 'true').
	self fails: (self parse: 'true not').! !

!MATrueConditionTest methodsFor: 'testing' stamp: 'lr 1/18/2006 09:22'!
testTrue
	self satisfies: self condition.! !

MAConditionTest subclass: #MAPluggableConditionTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Magritte-Tests-Condition'!

!MAPluggableConditionTest class methodsFor: 'testing' stamp: 'lr 1/16/2006 11:01'!
isAbstract
	^ false! !

!MAPluggableConditionTest methodsFor: 'private' stamp: 'lr 1/18/2006 09:02'!
actualClass
	^ MASelectorCondition! !

!MAPluggableConditionTest methodsFor: 'testing' stamp: 'lr 1/16/2006 11:02'!
testParsingBinary
	self fails: (self parse: 'true = false').
	self satisfies: (self parse: 'true = true').! !

!MAPluggableConditionTest methodsFor: 'testing' stamp: 'lr 1/16/2006 11:02'!
testParsingKeyword
	self fails: (self parse: '1 between: 2 and: 3').
	self satisfies: (self parse: '2 between: 1 and: 3').! !

!MAPluggableConditionTest methodsFor: 'testing' stamp: 'lr 1/16/2006 11:02'!
testParsingUnary
	self fails: (self parse: 'nil notNil').
	self satisfies: (self parse: 'nil isNil').! !

MAConditionTest subclass: #MASelectorConditionTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Magritte-Tests-Condition'!

MASelectorConditionTest subclass: #MAQueryConditionTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Magritte-Tests-Condition'!

!MAQueryConditionTest class methodsFor: 'testing' stamp: 'lr 12/5/2005 20:58'!
isAbstract
	^ false! !

!MAQueryConditionTest methodsFor: 'private' stamp: 'lr 1/18/2006 09:36'!
actualClass
	^ MAQueryCondition! !

!MASelectorConditionTest class methodsFor: 'testing' stamp: 'lr 12/5/2005 20:58'!
isAbstract
	^ false! !

!MASelectorConditionTest methodsFor: 'private' stamp: 'lr 1/18/2006 09:02'!
actualClass
	^ MASelectorCondition! !

MAObjectTest subclass: #MADescriptionTest
	instanceVariableNames: 'description'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Magritte-Tests-Description'!

MADescriptionTest subclass: #MAContainerTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Magritte-Tests-Description'!

!MAContainerTest class methodsFor: 'testing' stamp: 'lr 12/5/2005 20:58'!
isAbstract
	^ false! !

!MAContainerTest methodsFor: 'private' stamp: 'lr 12/5/2005 20:58'!
actualClass
	^ MAContainer! !

!MAContainerTest methodsFor: 'accessing' stamp: 'lr 11/28/2005 19:15'!
child1
	^ MAStringDescription selector: #child1 label: 'child1' priority: 1.! !

!MAContainerTest methodsFor: 'accessing' stamp: 'lr 11/28/2005 19:15'!
child2
	^ MANumberDescription selector: #child2 label: 'child2' priority: 2.! !

!MAContainerTest methodsFor: 'accessing' stamp: 'lr 11/28/2005 19:15'!
child3
	^ MAClassDescription selector: #child3 label: 'child3' priority: 3.! !

!MAContainerTest methodsFor: 'testing-adding' stamp: 'lr 5/8/2005 20:30'!
testAdd
	self description add: self child1.
	self assert: (self description size = 1).
	self assert: (self description includes: self child1).
	
	self description add: self child2.
	self assert: (self description size = 2).
	self assert: (self description includes: self child1).
	self assert: (self description includes: self child2).! !

!MAContainerTest methodsFor: 'testing-adding' stamp: 'lr 11/28/2005 19:51'!
testAddAll
	self description 
		addAll: (Array with: self child1 with: self child2).
	
	self assert: (self description size = 2).
	self assert: (self description includes: self child1).
	self assert: (self description includes: self child2).! !

!MAContainerTest methodsFor: 'testing-converting' stamp: 'lr 5/8/2005 20:30'!
testAsContainer
	self assert: self description asContainer = self description.
	self assert: self description asContainer == self description.! !

!MAContainerTest methodsFor: 'testing-accessing' stamp: 'lr 5/8/2005 20:30'!
testChildren
	self assert: self description children isCollection.
	self assert: self description children isEmpty.! !

!MAContainerTest methodsFor: 'testing-enumerating' stamp: 'lr 7/7/2005 15:08'!
testCollect
	| collected |
	self description add: self child1; add: self child2.
	collected := self description collect: [ :each | each ].
	self assert: self description = collected.
	self deny: self description == collected.
	
	collected := self description collect: [ :each | each copy ].
	self assert: self description = collected.
	self deny: self description == collected.
	
	collected := self description collect: [ :each | 
		each copy
			accessor: (MASelectorAccessor selector: #foo);
			yourself ].
	self deny: self description = collected.
	self deny: self description == collected.


! !

!MAContainerTest methodsFor: 'testing-operators' stamp: 'lr 11/28/2005 19:50'!
testConcatenate
	| concatenate |
	concatenate := self child1 , self child2.
	self assert: concatenate size = 2.
	self assert: concatenate children first = self child1.
	self assert: concatenate children second = self child2.
	
	concatenate := self child1 , self child2 , self child3.
	self assert: concatenate size = 3.
	self assert: concatenate children first = self child1.
	self assert: concatenate children second = self child2.
	self assert: concatenate children third = self child3.
	! !

!MAContainerTest methodsFor: 'testing-copying' stamp: 'lr 5/8/2005 20:30'!
testCopy
	self description add: self child1; add: self child2.
	super testCopy.
	
	self deny: self description copy children == self description children.
	self assert: self description copy children first = self description children first.
	self assert: self description copy children second = self description children second.! !

!MAContainerTest methodsFor: 'testing-copying' stamp: 'lr 11/14/2005 22:02'!
testCopyEmpty
	self description add: self child1; add: self child2.
	self assert: self description copyEmpty isEmpty.! !

!MAContainerTest methodsFor: 'testing-copying' stamp: 'lr 11/28/2005 19:52'!
testCopyFromTo
	| copied |
	self description add: self child1; add: self child2; add: self child3.
	copied := self description copyFrom: 2 to: 3.
	
	self assert: copied ~= self description.

	self assert: copied size = 2.
	self assert: copied children first = self child2.
	self assert: copied children second = self child3.! !

!MAContainerTest methodsFor: 'testing-enumerating' stamp: 'lr 5/8/2005 20:30'!
testDetect
	self description add: self child1.
	self assert: (self description 
		detect: [ :each | self child1 = each ]) = self child1.
	self should: [ self description 
		detect: [ :each | self child2 = each ] ] raise: Error.! !

!MAContainerTest methodsFor: 'testing-enumerating' stamp: 'lr 5/8/2005 20:30'!
testDetectIfNone
	self description add: self child1.
	self assert: (self description 
		detect: [ :each | self child1 = each ] 
		ifNone: [ 123 ]) = self child1.
	self assert: (self description 
		detect: [ :each | self child2 = each ] 
		ifNone: [ 123 ]) = 123.! !

!MAContainerTest methodsFor: 'testing-enumerating' stamp: 'lr 5/8/2005 20:30'!
testDo
	| collection |
	collection := self description class defaultCollection.
	self description add: self child1; add: self child2.
	self description do: [ :each | collection add: each ].
	self assert: (self description children hasEqualElements: collection).! !

!MAContainerTest methodsFor: 'testing-enumerating' stamp: 'lr 5/8/2005 20:30'!
testDoSepratedBy
	| collection |
	collection := OrderedCollection new.
	self description add: self child1; add: self child2.
	self description 
		do: [ :each | collection add: each ]
		separatedBy: [ collection add: nil ].
	self assert: collection size = 3.
	self assert: collection first = self child1.
	self assert: collection second isNil.
	self assert: collection third = self child2.! !

!MAContainerTest methodsFor: 'testing-testing' stamp: 'lr 5/8/2005 20:30'!
testEmpty
	self assert: self description isEmpty.
	self description add: self child1.
	self deny: self description isEmpty.! !

!MAContainerTest methodsFor: 'testing-testing' stamp: 'lr 5/8/2005 20:30'!
testHasChildren
	super testHasChildren.
	self description add: self child1.
	self assert: self description hasChildren.! !

!MAContainerTest methodsFor: 'testing-testing' stamp: 'lr 5/8/2005 20:30'!
testIncludes
	self deny: (self description includes: self child1).
	self description add: self child1.
	self assert: (self description includes: self child1).! !

!MAContainerTest methodsFor: 'testing-enumerating' stamp: 'lr 5/8/2005 20:30'!
testInjectInto
	self description add: self child1; add: self child2.
	self assert: (self description 
		inject: 'start'
		into: [ :result :each | result , ' ' , each label ]) = 'start child1 child2'.! !

!MAContainerTest methodsFor: 'testing-operators' stamp: 'lr 11/28/2005 19:18'!
testIntersection
	| a b union |
	a := self child1 , self child2.
	b := self child2 , self child3.
	union := a intersection: b.

	self assert: (union size) = 1.
	self deny: (union includes: self child1).
	self assert: (union includes: self child2).
	self deny: (union includes: self child3).
! !

!MAContainerTest methodsFor: 'testing-testing' stamp: 'lr 5/8/2005 20:30'!
testIsContainer
	self assert: self description isContainer.! !

!MAContainerTest methodsFor: 'testing-moving' stamp: 'lr 11/28/2005 20:04'!
testMoveDown
	self description add: self child1; add: self child2.
	self assert: self description children first = self child1.
	self assert: self description children second = self child2.
	
	self description moveDown: self child1.
	self assert: self description children first = self child2.
	self assert: self description children second = self child1.

	self description moveDown: self child1.
	self assert: self description children first = self child2.
	self assert: self description children second = self child1.! !

!MAContainerTest methodsFor: 'testing-moving' stamp: 'lr 11/28/2005 20:04'!
testMoveUp
	self description add: self child1; add: self child2.
	self assert: self description children first = self child1.
	self assert: self description children second = self child2.

	self description moveUp: self child2.
	self assert: self description children first = self child2.
	self assert: self description children second = self child1.

	self description moveUp: self child2.
	self assert: self description children first = self child2.
	self assert: self description children second = self child1.! !

!MAContainerTest methodsFor: 'testing-testing' stamp: 'lr 5/8/2005 20:30'!
testNotEmpty
	self deny: self description notEmpty.
	self description add: self child1.
	self assert: self description notEmpty.! !

!MAContainerTest methodsFor: 'testing-indentity' stamp: 'lr 11/28/2005 19:53'!
testReferenceStream
	| object |
	self description add: self child1; add: self child2.
	object := super testReferenceStream.
	
	self assert: object children first = self child1.
	self deny: object children first == self child1.
	
	self assert: object children second = self child2.
	self deny: object children second == self child2.! !

!MAContainerTest methodsFor: 'testing-enumerating' stamp: 'lr 7/7/2005 15:14'!
testReject
	| rejected |
	self description add: self child1; add: self child2.
	
	rejected := self description reject: [ :each | false ].
	self assert: self description = rejected.

	rejected := self description reject: [ :each | true ].
	self assert: rejected isEmpty.! !

!MAContainerTest methodsFor: 'testing-removing' stamp: 'lr 5/8/2005 20:30'!
testRemove
	self description add: self child1; add: self child2.

	self description remove: self child1.
	self assert: self description size = 1.
	self deny: (self description includes: self child1).
	self assert: (self description includes: self child2).

	self description remove: self child2.
	self assert: self description isEmpty.! !

!MAContainerTest methodsFor: 'testing-removing' stamp: 'lr 5/8/2005 20:30'!
testRemoveAll
	self description add: self child1; add: self child2.

	self description removeAll.
	self assert: self description isEmpty.! !

!MAContainerTest methodsFor: 'testing-enumerating' stamp: 'lr 7/7/2005 15:15'!
testSelect
	| selected |
	self description add: self child1; add: self child2.
	
	selected := self description select: [ :each | true ].
	self assert: self description = selected.
	
	selected := self description select: [ :each | false ].
	self assert: selected isEmpty.! !

!MAContainerTest methodsFor: 'testing-accessing' stamp: 'lr 11/28/2005 19:51'!
testSize
	self assert: self description size isZero.
	self description add: self child1.
	self assert: self description size = 1.
	self description add: self child2.
	self assert: self description size = 2.
	self description add: self child3.
	self assert: self description size = 3.! !

!MAContainerTest methodsFor: 'testing-operators' stamp: 'lr 11/28/2005 19:16'!
testUnion
	| a b union |
	a := self child1 , self child2.
	b := self child2 , self child3.
	union := a union: b.

	self assert: (union size) = 3.
	self assert: (union includes: self child1).
	self assert: (union includes: self child2).
	self assert: (union includes: self child3).
! !

!MAContainerTest methodsFor: 'testing-enumerating' stamp: 'lr 10/13/2005 19:11'!
testWithDo
	self description add: self child1; add: self child2.
	self description with: self description children 
		do: [ :first :second | self assert: first = second ].! !

!MAContainerTest methodsFor: 'testing-enumerating' stamp: 'lr 11/10/2005 21:27'!
testWithIndexDo
	self description add: self child1; add: self child2.
	self description withIndexDo: [ :each :index | 
		index = 1
			ifTrue: [ self assert: self child1 = each ]
			ifFalse: [
				index = 2
					ifTrue: [ self assert: self child2 = each ]
					ifFalse: [ self assert: false ] ] ].! !

MAContainerTest subclass: #MAPriorityContainerTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Magritte-Tests-Description'!

!MAPriorityContainerTest class methodsFor: 'testing' stamp: 'lr 12/5/2005 20:58'!
isAbstract
	^ false! !

!MAPriorityContainerTest methodsFor: 'private' stamp: 'lr 12/5/2005 20:58'!
actualClass
	^ MAPriorityContainer! !

!MAPriorityContainerTest methodsFor: 'testing-moving' stamp: 'lr 11/28/2005 20:10'!
testMoveDown
	self should: [ super testMoveDown ] raise: Error.! !

!MAPriorityContainerTest methodsFor: 'testing-moving' stamp: 'lr 11/28/2005 20:10'!
testMoveUp
	self should: [ super testMoveUp ] raise: Error.! !

MAContainerTest subclass: #MAReportContainerTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Magritte-Tests-Description'!

!MAReportContainerTest class methodsFor: 'testing' stamp: 'lr 12/5/2005 20:58'!
isAbstract
	^ false! !

!MAReportContainerTest methodsFor: 'private' stamp: 'lr 12/5/2005 20:58'!
actualClass
	^ MAReportContainer! !

!MAReportContainerTest methodsFor: 'testing-accessing' stamp: 'lr 11/28/2005 19:07'!
testShowFilter
	self instance showFilter: true.
	self assert: self instance showFilter.

	self instance showFilter: false.
	self deny: self instance showFilter.! !

!MADescriptionTest class methodsFor: 'testing' stamp: 'lr 12/5/2005 20:58'!
isAbstract
	^ true! !

!MADescriptionTest class methodsFor: 'testing' stamp: 'lr 5/8/2005 20:33'!
shouldInheritSelectors
	^ true! !

!MADescriptionTest methodsFor: 'private' stamp: 'lr 12/5/2005 20:58'!
actualClass
	^ MADescription! !

!MADescriptionTest methodsFor: 'accessing' stamp: 'lr 5/8/2005 20:30'!
description
	^ description! !

!MADescriptionTest methodsFor: 'private' stamp: 'lr 12/21/2005 20:24'!
descriptionInstance
	^ (self actualClass new)
		accessor: MANullAccessor new;
		yourself.! !

!MADescriptionTest methodsFor: 'accessing' stamp: 'lr 5/8/2005 20:30'!
instance
	^ description! !

!MADescriptionTest methodsFor: 'running' stamp: 'lr 9/23/2005 20:10'!
setUp
	super setUp.
	description := self descriptionInstance.! !

!MADescriptionTest methodsFor: 'testing-accessing' stamp: 'lr 10/13/2005 19:03'!
testAccessor
	self description accessor: (MASelectorAccessor selector: #foo).
	self assert: self description accessor selector = #foo.! !

!MADescriptionTest methodsFor: 'testing-converting' stamp: 'lr 5/8/2005 20:30'!
testAsContainer
	self subclassResponsibility.! !

!MADescriptionTest methodsFor: 'testing-accessing' stamp: 'lr 5/8/2005 20:30'!
testComment
	self description comment: 'bar'.
	self assert: self description comment = 'bar'.! !

!MADescriptionTest methodsFor: 'testing-copying' stamp: 'lr 9/23/2005 20:25'!
testCopyAccessor
	self assert: self description copy accessor = self description accessor.
	self deny: self description copy accessor == self description accessor.! !

!MADescriptionTest methodsFor: 'testing-identity' stamp: 'lr 5/8/2005 20:30'!
testDictionaryKey
	| dictionary |
	dictionary := Dictionary new.
	
	dictionary at: self instance put: 1.
	self assert: (dictionary at: self instance) = 1.
	
	dictionary at: self instance put: 2.
	self assert: (dictionary at: self instance) = 2.! !

!MADescriptionTest methodsFor: 'testing-testing' stamp: 'lr 5/8/2005 20:30'!
testHasChildren
	self deny: self description hasChildren.! !

!MADescriptionTest methodsFor: 'testing-testing' stamp: 'lr 5/8/2005 20:30'!
testHasComment
	self description comment: nil.
	self deny: self description hasComment.
	
	self description comment: ''.
	self deny: self description hasComment.
	
	self description comment: 'comment'.
	self assert:  self description hasComment.! !

!MADescriptionTest methodsFor: 'testing-testing' stamp: 'lr 5/8/2005 20:30'!
testHasLabel
	self description label: nil.
	self deny: self description hasLabel.
	
	self description label: ''.
	self deny: self description hasLabel.
	
	self description label: 'label'.
	self assert:  self description hasLabel.! !

!MADescriptionTest methodsFor: 'testing-testing' stamp: 'lr 5/8/2005 20:30'!
testIsContainer
	self deny: self description isContainer.! !

!MADescriptionTest methodsFor: 'testing-testing' stamp: 'lr 9/15/2005 12:58'!
testIsDescription
	self assert: self description isDescription.! !

!MADescriptionTest methodsFor: 'testing-accessing' stamp: 'lr 5/8/2005 20:30'!
testLabel
	self description label: 'foo'.
	self assert: self description label = 'foo'.! !

!MADescriptionTest methodsFor: 'testing-actions' stamp: 'lr 10/13/2005 17:51'!
testPersistent
	self description beEphemeral.
	self deny: self description persistent.
	self deny: self description isPersistent.
	
	self description bePersistent.
	self assert: self description persistent.
	self assert: self description isPersistent.! !

!MADescriptionTest methodsFor: 'testing-accessing' stamp: 'lr 5/8/2005 20:30'!
testPriority
	self description priority: 123.
	self assert: self description priority = 123.! !

!MADescriptionTest methodsFor: 'testing-actions' stamp: 'lr 10/13/2005 17:54'!
testReadonly
	self description beReadonly.
	self assert: self description readonly.
	self assert: self description isReadonly.
	
	self description beWriteable.
	self deny: self description readonly.
	self deny: self description isReadonly.! !

!MADescriptionTest methodsFor: 'testing-actions' stamp: 'lr 5/8/2005 20:30'!
testRequired
	self description beRequired.
	self assert: self description required.
	self assert: self description isRequired.
	
	self description beOptional.
	self deny: self description required.
	self deny: self description isRequired.! !

!MADescriptionTest methodsFor: 'testing-identity' stamp: 'lr 5/8/2005 20:30'!
testSetElement
	| set |
	set := Set new.
	
	set add: self instance.
	self assert: set size = 1.
	self assert: (set includes: self instance).

	set add: self instance.
	self assert: set size = 1.
	self assert: (set includes: self instance).! !

!MADescriptionTest methodsFor: 'testing-actions' stamp: 'lr 5/8/2005 20:30'!
testVisible
	self description beHidden.
	self deny: self description visible.
	self deny: self description isVisible.
	
	self description beVisible.
	self assert: self description visible.
	self assert: self description isVisible.! !

MADescriptionTest subclass: #MAElementDescriptionTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Magritte-Tests-Description'!

MAElementDescriptionTest subclass: #MABooleanDescriptionTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Magritte-Tests-Description'!

!MABooleanDescriptionTest class methodsFor: 'testing' stamp: 'lr 12/5/2005 20:58'!
isAbstract
	^ false! !

!MABooleanDescriptionTest methodsFor: 'private' stamp: 'lr 12/5/2005 20:58'!
actualClass
	^ MABooleanDescription! !

!MABooleanDescriptionTest methodsFor: 'private' stamp: 'lr 5/8/2005 20:29'!
includedInstance
	^ true! !

MAElementDescriptionTest subclass: #MAClassDescriptionTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Magritte-Tests-Description'!

!MAClassDescriptionTest class methodsFor: 'testing' stamp: 'lr 12/5/2005 20:58'!
isAbstract
	^ false! !

!MAClassDescriptionTest methodsFor: 'private' stamp: 'lr 12/5/2005 20:58'!
actualClass
	^ MAClassDescription! !

!MAClassDescriptionTest methodsFor: 'private' stamp: 'lr 9/15/2005 11:28'!
includedInstance
	^ String! !

!MAClassDescriptionTest methodsFor: 'private' stamp: 'lr 11/13/2005 11:37'!
shouldSkipStringTests
	^ true! !

MAElementDescriptionTest subclass: #MAColorDescriptionTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Magritte-Tests-Description'!

!MAColorDescriptionTest class methodsFor: 'testing' stamp: 'lr 12/5/2005 20:58'!
isAbstract
	^ false! !

!MAColorDescriptionTest methodsFor: 'private' stamp: 'lr 12/5/2005 20:58'!
actualClass
	^ MAColorDescription! !

!MAColorDescriptionTest methodsFor: 'private' stamp: 'lr 7/7/2005 15:44'!
includedInstance
	^ Color blue.! !

!MAElementDescriptionTest class methodsFor: 'testing' stamp: 'lr 12/5/2005 20:58'!
isAbstract
	^ true! !

!MAElementDescriptionTest methodsFor: 'private' stamp: 'lr 12/5/2005 20:58'!
actualClass
	^ MAElementDescription! !

!MAElementDescriptionTest methodsFor: 'private' stamp: 'lr 5/8/2005 20:31'!
emptyInstance
	^ String new! !

!MAElementDescriptionTest methodsFor: 'private' stamp: 'lr 5/8/2005 20:31'!
includedInstance
	self subclassResponsibility! !

!MAElementDescriptionTest methodsFor: 'private' stamp: 'lr 10/13/2005 16:58'!
includedInstanceString
	^ MAStringWriter write: self includedInstance description: self descriptionInstance.! !

!MAElementDescriptionTest methodsFor: 'private' stamp: 'lr 5/8/2005 20:31'!
invalidInstance
	^ Object new! !

!MAElementDescriptionTest methodsFor: 'private' stamp: 'lr 5/8/2005 20:31'!
nullInstance
	^ nil! !

!MAElementDescriptionTest methodsFor: 'private' stamp: 'lr 11/13/2005 11:35'!
shouldSkipStringTests
	^ false! !

!MAElementDescriptionTest methodsFor: 'testing-validation' stamp: 'lr 1/18/2006 10:00'!
testAddCondition
	self description 
		addCondition: [ :value | value isNil ] asCondition.

	self assert: self description conditions size = 1.
	self assert: self description conditions first key isCondition.
	self assert: self description conditions first value isString.! !

!MAElementDescriptionTest methodsFor: 'testing-validation' stamp: 'lr 1/18/2006 10:00'!
testAddConditionLabelled
	self description 
		addCondition: [ :value | value isNil ] asCondition
		labelled: 'ist net nil'.

	self assert: self description conditions size = 1.
	self assert: self description conditions first key isCondition.
	self assert: self description conditions first value = 'ist net nil'.! !

!MAElementDescriptionTest methodsFor: 'testing-converting' stamp: 'lr 5/8/2005 20:31'!
testAsContainer
	self assert: (self description asContainer size) = 1.
	self assert: (self description asContainer includes: self description).! !

!MAElementDescriptionTest methodsFor: 'testing-operators' stamp: 'lr 5/8/2005 20:31'!
testConcatenation
	| child1 child2 concatenate |
	child1 := self description copy.
	child2 := self description copy.
	
	concatenate := child1 , child2.
	self assert: concatenate size = 2.
	self assert: concatenate children first = child1.
	self assert: concatenate children second = child2.
	
	concatenate := child1 , concatenate.
	self assert: concatenate size = 3.
	self assert: concatenate children first = child1.
	self assert: concatenate children second = child1.
	self assert: concatenate children third = child2.! !

!MAElementDescriptionTest methodsFor: 'testing-copying' stamp: 'lr 9/23/2005 20:19'!
testCopy
	super testCopy.
	self assert: self description copy default = self description default.! !

!MAElementDescriptionTest methodsFor: 'testing-accessing' stamp: 'lr 5/8/2005 20:31'!
testDefault
	self description default: self includedInstance.
	self assert: self description default = self includedInstance.! !

!MAElementDescriptionTest methodsFor: 'testing-strings' stamp: 'lr 11/13/2005 11:35'!
testFromString
	self shouldSkipStringTests ifTrue: [ ^ self ].
	self assert: (self description 
		fromString: self includedInstanceString)
			= self includedInstance.
	self assert: (self description 
		fromString: self includedInstanceString
		reader: self description stringReader)
			= self includedInstance.
	self assert: (self description 
		fromString: self includedInstanceString
		reader: self description stringReader new)
			= self includedInstance.! !

!MAElementDescriptionTest methodsFor: 'testing-strings' stamp: 'lr 11/13/2005 11:35'!
testFromStringCollection
	self shouldSkipStringTests ifTrue: [ ^ self ].
	self assert: (self description 
		fromStringCollection: (Array 
			with: self includedInstanceString 
			with: self includedInstanceString))
				= (Array 
					with: self includedInstance
					with: self includedInstance).
	self assert: (self description 
		fromStringCollection: (Array 
			with: self includedInstanceString 
			with: self includedInstanceString)
		reader: self description stringReader)
				= (Array 
					with: self includedInstance
					with: self includedInstance).! !

!MAElementDescriptionTest methodsFor: 'testing-strings' stamp: 'lr 11/13/2005 11:35'!
testFromStringNull
	self shouldSkipStringTests ifTrue: [ ^ self ].
	self assert: (self description 
		fromString: self emptyInstance) isNil.
	self assert: (self description 
		fromString: self emptyInstance
		reader: self description stringReader) isNil.
	self assert: (self description 
		fromString: self emptyInstance
		reader: self description stringReader new) isNil.! !

!MAElementDescriptionTest methodsFor: 'testing-accessing' stamp: 'lr 5/8/2005 20:31'!
testKind
	self assert: (self includedInstance isKindOf: self description kind).! !

!MAElementDescriptionTest methodsFor: 'testing-testing' stamp: 'lr 1/18/2006 16:26'!
testSatisfied
	self assert: (self description isSatisfiedBy: self includedInstance).
	self assert: (self description isSatisfiedBy: self nullInstance).
	self deny: (self description isSatisfiedBy: self invalidInstance).! !

!MAElementDescriptionTest methodsFor: 'testing-accessing' stamp: 'lr 10/13/2005 17:55'!
testStringReader
	| object |
	self description stringReader: (object := MAStringReader new).
	self assert: self description stringReader = object.! !

!MAElementDescriptionTest methodsFor: 'testing-accessing' stamp: 'lr 10/13/2005 17:20'!
testStringWriter
	| object |
	self description stringWriter: (object := MAStringWriter new).
	self assert: self description stringWriter = object.! !

!MAElementDescriptionTest methodsFor: 'testing-strings' stamp: 'lr 11/13/2005 11:35'!
testToString
	self shouldSkipStringTests ifTrue: [ ^ self ].
	self assert: (self description 
		toString: self includedInstance) 
			= self includedInstanceString.
	self assert: (self description 
		toString: self includedInstance 
		writer: self description stringWriter) 
			= self includedInstanceString.
	self assert: (self description 
		toString: self includedInstance 
		writer: self description stringWriter new) 
			= self includedInstanceString.! !

!MAElementDescriptionTest methodsFor: 'testing-strings' stamp: 'lr 11/13/2005 11:35'!
testToStringCollection
	self shouldSkipStringTests ifTrue: [ ^ self ].
	self assert: (self description 
		toStringCollection: (Array
			with: self includedInstance
			with: self includedInstance))
				= (Array 
					with: self includedInstanceString
					with: self includedInstanceString).
	self assert: (self description 
		toStringCollection: (Array
			with: self includedInstance
			with: self includedInstance)
		writer: self description stringWriter)
			= (Array 
				with: self includedInstanceString
				with: self includedInstanceString).! !

!MAElementDescriptionTest methodsFor: 'testing-strings' stamp: 'lr 11/13/2005 11:35'!
testToStringFromString
	self shouldSkipStringTests ifTrue: [ ^ self ].
	self assert: (self description 
		fromString: (self description 
			toString: self includedInstance)) 
				= self includedInstance.
	self assert: (self description 
		fromString: (self description 
			toString: self includedInstance
			writer: self description stringWriter)
		reader: self description stringReader) 
				= self includedInstance.
	self assert: (self description 
		fromString: (self description 
			toString: self includedInstance
			writer: self description stringWriter new)
		reader: self description stringReader new) 
				= self includedInstance.! !

!MAElementDescriptionTest methodsFor: 'testing-strings' stamp: 'lr 11/13/2005 11:36'!
testToStringNull
	self shouldSkipStringTests ifTrue: [ ^ self ].
	self assert: (self description 
		toString: self nullInstance) 
			= self description undefined.
	self assert: (self description 
		toString: self nullInstance 
		writer: self description stringWriter) 
			= self description undefined.
	self assert: (self description 
		toString: self nullInstance 
		writer: self description stringWriter new) 
			= self description undefined.
	! !

!MAElementDescriptionTest methodsFor: 'testing-strings' stamp: 'lr 11/13/2005 11:36'!
testToStringUndefined
	self shouldSkipStringTests ifTrue: [ ^ self ].
	self description undefined: 'n/a'.
	self assert: (self description 
		toString: self nullInstance) 
			= 'n/a'.
	self assert: (self description 
		toString: self nullInstance 
		writer: self description stringWriter) 
			= 'n/a'.
	self assert: (self description 
		toString: self nullInstance 
		writer: self description stringWriter new) 
			= 'n/a'.! !

!MAElementDescriptionTest methodsFor: 'testing-accessing' stamp: 'lr 9/15/2005 10:39'!
testUndefined
	self description undefined: 'nop'.
	self assert: self description undefined = 'nop'.! !

!MAElementDescriptionTest methodsFor: 'testing-validation' stamp: 'lr 10/27/2005 17:28'!
testValidate
	self description beRequired.
	self
		shouldnt: [ self description validate: self includedInstance ]
		raise: MAValidationError.
	self
		should: [ self description validate: self invalidInstance ]
		raise: MAKindError.
	self
		should: [ self description validate: self nullInstance ]
		raise: MARequiredError.! !

!MAElementDescriptionTest methodsFor: 'testing-validation' stamp: 'lr 1/18/2006 10:02'!
testValidateConditions
	"This test might fail for MADateDescriptionTest, since there is a bug in Squeak."

	self description 
		addCondition: [ :value | value = self includedInstance ] asCondition
		labelled: 'included instance test'.
	self 
		shouldnt: [ self description validateConditions: self includedInstance ]
		raise: MAConditionError.
	self
		should: [ self description validateConditions: self invalidInstance ]
		raise: MAConditionError.

	self description 
		addCondition: [ :value | value = self invalidInstance ] asCondition
		labelled: 'invalid instance test'.
	self 
		should: [ self description validateConditions: self includedInstance ]
		raise: MAConditionError.
	self
		should: [ self description validateConditions: self invalidInstance ]
		raise: MAConditionError.! !

!MAElementDescriptionTest methodsFor: 'testing-validation' stamp: 'lr 10/27/2005 15:48'!
testValidateKind
	self
		should: [ self description validateKind: self invalidInstance ] 
		raise: MAKindError. 
	self
		shouldnt: [ self description validateKind: self includedInstance ] 
		raise: MAKindError.! !

!MAElementDescriptionTest methodsFor: 'testing-validation' stamp: 'lr 10/27/2005 15:47'!
testValidateRequired
	self description beOptional.
	self 
		shouldnt: [ self description validateRequired: self nullInstance ] 
		raise: MARequiredError. 
	self 
		shouldnt: [ self description validateRequired: self includedInstance ] 
		raise: MARequiredError.

	self description beRequired.
	self 
		should: [ self description validateRequired: self nullInstance ] 
		raise: MARequiredError. 
	self 
		shouldnt: [ self description validateRequired: self includedInstance ]
		raise: MARequiredError.! !

!MAElementDescriptionTest methodsFor: 'testing-validation' stamp: 'lr 10/27/2005 16:10'!
testValidateSpecific
	self 
		shouldnt: [ self description validateSpecific: self includedInstance ]
		raise: MARequiredError.! !

MAElementDescriptionTest subclass: #MAFileDescriptionTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Magritte-Tests-Description'!

!MAFileDescriptionTest class methodsFor: 'testing' stamp: 'lr 12/5/2005 20:58'!
isAbstract
	^ false! !

!MAFileDescriptionTest methodsFor: 'private' stamp: 'lr 12/5/2005 20:58'!
actualClass
	^ MAFileDescription! !

!MAFileDescriptionTest methodsFor: 'private' stamp: 'lr 8/10/2005 19:54'!
includedInstance
	^ MAFileModel new
		contents: 'Lukas Renggli';
		filename: 'author.txt';
		yourself.! !

!MAFileDescriptionTest methodsFor: 'private' stamp: 'lr 11/13/2005 11:38'!
shouldSkipStringTests
	^ true! !

MAElementDescriptionTest subclass: #MAMagnitudeDescriptionTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Magritte-Tests-Description'!

MAMagnitudeDescriptionTest subclass: #MADateDescriptionTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Magritte-Tests-Description'!

!MADateDescriptionTest class methodsFor: 'testing' stamp: 'lr 12/5/2005 20:58'!
isAbstract
	^ false! !

!MADateDescriptionTest methodsFor: 'private' stamp: 'lr 12/5/2005 20:58'!
actualClass
	^ MADateDescription! !

!MADateDescriptionTest methodsFor: 'private' stamp: 'lr 5/8/2005 20:30'!
includedInstance
	^ Date newDay: 11 month: 6 year: 1980.! !

!MADateDescriptionTest methodsFor: 'private' stamp: 'lr 10/19/2005 20:18'!
maxInstance
	^ Date newDay: 12 month: 6 year: 1980.! !

!MADateDescriptionTest methodsFor: 'private' stamp: 'lr 10/19/2005 20:21'!
minInstance
	^ Date newDay: 10 month: 6 year: 1980.! !

MAMagnitudeDescriptionTest subclass: #MADurationDescriptionTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Magritte-Tests-Description'!

!MADurationDescriptionTest class methodsFor: 'testing' stamp: 'lr 12/5/2005 20:58'!
isAbstract
	^ false! !

!MADurationDescriptionTest methodsFor: 'private' stamp: 'lr 12/5/2005 20:58'!
actualClass
	^ MADurationDescription! !

!MADurationDescriptionTest methodsFor: 'private' stamp: 'lr 5/8/2005 20:30'!
includedInstance
	^ Duration days: 1 hours: 2 minutes: 3 seconds: 4.! !

!MADurationDescriptionTest methodsFor: 'private' stamp: 'lr 10/19/2005 20:23'!
maxInstance
	^ Duration days: 2 hours: 2 minutes: 3 seconds: 4.! !

!MADurationDescriptionTest methodsFor: 'private' stamp: 'lr 10/19/2005 20:22'!
minInstance
	^ Duration days: 0 hours: 2 minutes: 3 seconds: 4.! !

!MAMagnitudeDescriptionTest class methodsFor: 'testing' stamp: 'lr 12/5/2005 20:58'!
isAbstract
	^ true! !

!MAMagnitudeDescriptionTest methodsFor: 'private' stamp: 'lr 12/5/2005 20:58'!
actualClass
	^ MAMagnitudeDescription! !

!MAMagnitudeDescriptionTest methodsFor: 'private' stamp: 'lr 10/19/2005 20:18'!
maxInstance
	self subclassResponsibility! !

!MAMagnitudeDescriptionTest methodsFor: 'private' stamp: 'lr 10/19/2005 20:18'!
minInstance
	self subclassResponsibility! !

!MAMagnitudeDescriptionTest methodsFor: 'testing' stamp: 'lr 10/19/2005 20:17'!
testInfToInf
	self assert: self description min isNil.
	self assert: self description max isNil.
	
	self assert: (self description isSatisfiedBy: self minInstance).
	self assert: (self description isSatisfiedBy: self includedInstance).
	self assert: (self description isSatisfiedBy: self maxInstance).
	
	! !

!MAMagnitudeDescriptionTest methodsFor: 'testing' stamp: 'lr 10/19/2005 20:17'!
testInfToVal
	self description max: self includedInstance.

	self assert: self description min isNil.
	self assert: self description max = self includedInstance.
	
	self assert: (self description isSatisfiedBy: self minInstance).
	self assert: (self description isSatisfiedBy: self includedInstance).
	self deny: (self description isSatisfiedBy: self maxInstance).
	
	! !

!MAMagnitudeDescriptionTest methodsFor: 'testing-accessing' stamp: 'lr 10/19/2005 20:16'!
testMax
	self description max: self maxInstance.
	self assert: self description max = self maxInstance.! !

!MAMagnitudeDescriptionTest methodsFor: 'testing-accessing' stamp: 'lr 10/19/2005 20:16'!
testMin
	self description min: self minInstance.
	self assert: self description min = self minInstance.! !

!MAMagnitudeDescriptionTest methodsFor: 'testing-accessing' stamp: 'lr 10/19/2005 20:17'!
testMinMax
	self description min: self minInstance max: self maxInstance.
	self assert: self description min = self minInstance.
	self assert: self description max = self maxInstance.! !

!MAMagnitudeDescriptionTest methodsFor: 'testing' stamp: 'lr 10/19/2005 20:17'!
testValToInf
	self description min: self includedInstance.

	self assert: self description min = self includedInstance.
	self assert: self description max isNil.
	
	self deny: (self description isSatisfiedBy: self minInstance).
	self assert: (self description isSatisfiedBy: self includedInstance).
	self assert: (self description isSatisfiedBy: self maxInstance).
	
	! !

!MAMagnitudeDescriptionTest methodsFor: 'testing' stamp: 'lr 10/19/2005 20:17'!
testValToVal
	self description min: self includedInstance.
	self description max: self includedInstance.

	self assert: self description min = self includedInstance.
	self assert: self description max = self includedInstance.
	
	self deny: (self description isSatisfiedBy: self minInstance).
	self assert: (self description isSatisfiedBy: self includedInstance).
	self deny: (self description isSatisfiedBy: self maxInstance).
	
	! !

MAMagnitudeDescriptionTest subclass: #MANumberDescriptionTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Magritte-Tests-Description'!

!MANumberDescriptionTest class methodsFor: 'testing' stamp: 'lr 12/5/2005 20:58'!
isAbstract
	^ false! !

!MANumberDescriptionTest methodsFor: 'private' stamp: 'lr 12/5/2005 20:58'!
actualClass
	^ MANumberDescription! !

!MANumberDescriptionTest methodsFor: 'private' stamp: 'lr 8/25/2005 10:35'!
includedInstance
	^ 2.7182! !

!MANumberDescriptionTest methodsFor: 'private' stamp: 'lr 10/19/2005 20:23'!
maxInstance
	^ 3.1415! !

!MANumberDescriptionTest methodsFor: 'private' stamp: 'lr 10/19/2005 20:22'!
minInstance
	^ 1.6180! !

MAMagnitudeDescriptionTest subclass: #MATimeDescriptionTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Magritte-Tests-Description'!

!MATimeDescriptionTest class methodsFor: 'testing' stamp: 'lr 12/5/2005 20:58'!
isAbstract
	^ false! !

!MATimeDescriptionTest methodsFor: 'private' stamp: 'lr 12/5/2005 20:58'!
actualClass
	^ MATimeDescription! !

!MATimeDescriptionTest methodsFor: 'private' stamp: 'lr 5/8/2005 20:33'!
includedInstance
	^ Time hour: 11 minute: 33 second: 12.! !

!MATimeDescriptionTest methodsFor: 'private' stamp: 'lr 10/19/2005 20:23'!
maxInstance
	^ Time hour: 12 minute: 33 second: 12.! !

!MATimeDescriptionTest methodsFor: 'private' stamp: 'lr 10/19/2005 20:22'!
minInstance
	^ Time hour: 10 minute: 33 second: 12.! !

MAMagnitudeDescriptionTest subclass: #MATimeStampDescriptionTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Magritte-Tests-Description'!

!MATimeStampDescriptionTest class methodsFor: 'testing' stamp: 'lr 12/5/2005 20:58'!
isAbstract
	^ false! !

!MATimeStampDescriptionTest methodsFor: 'private' stamp: 'lr 12/5/2005 20:58'!
actualClass
	^ MATimeStampDescription! !

!MATimeStampDescriptionTest methodsFor: 'private' stamp: 'lr 8/25/2005 10:36'!
includedInstance
	^ TimeStamp year: 1980 month: 6 day: 11 hour: 11 minute: 38 second: 12.! !

!MATimeStampDescriptionTest methodsFor: 'private' stamp: 'lr 10/19/2005 20:23'!
maxInstance
	^ TimeStamp year: 1980 month: 6 day: 12 hour: 11 minute: 38 second: 12.! !

!MATimeStampDescriptionTest methodsFor: 'private' stamp: 'lr 10/19/2005 20:22'!
minInstance
	^ TimeStamp year: 1980 month: 6 day: 10 hour: 11 minute: 38 second: 12.! !

MAElementDescriptionTest subclass: #MAReferenceDescriptionTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Magritte-Tests-Description'!

MAReferenceDescriptionTest subclass: #MAOptionDescriptionTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Magritte-Tests-Description'!

MAOptionDescriptionTest subclass: #MAMultipleOptionDescriptionTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Magritte-Tests-Description'!

!MAMultipleOptionDescriptionTest class methodsFor: 'accessing-default' stamp: 'lr 9/26/2005 09:57'!
defaultUnique
	^ false! !

!MAMultipleOptionDescriptionTest class methodsFor: 'testing' stamp: 'lr 12/5/2005 20:58'!
isAbstract
	^ false! !

!MAMultipleOptionDescriptionTest methodsFor: 'private' stamp: 'lr 12/5/2005 20:58'!
actualClass
	^ MAMultipleOptionDescription! !

!MAMultipleOptionDescriptionTest methodsFor: 'private' stamp: 'lr 9/26/2005 09:24'!
includedInstance
	^ self optionInstances copyFrom: 1 to: 2.! !

!MAMultipleOptionDescriptionTest methodsFor: 'testing-properties' stamp: 'lr 11/11/2005 15:49'!
testOrdered
	self description beOrdered.
	self assert: self description isOrdered.
	self assert: self description ordered.
	
	self description beUnordered.
	self deny: self description isOrdered.
	self deny: self description ordered.! !

!MAMultipleOptionDescriptionTest methodsFor: 'testing-properties' stamp: 'lr 11/11/2005 14:14'!
testSorted
	self description beDistinct.
	self assert: self description isDistinct.
	self assert: self description distinct.
	
	self description beIndefinite.
	self deny: self description isDistinct.
	self deny: self description distinct.! !

!MAOptionDescriptionTest class methodsFor: 'testing' stamp: 'lr 12/5/2005 20:58'!
isAbstract
	^ true! !

!MAOptionDescriptionTest methodsFor: 'private' stamp: 'lr 12/5/2005 20:58'!
actualClass
	^ MAOptionDescription! !

!MAOptionDescriptionTest methodsFor: 'private' stamp: 'lr 9/26/2005 09:13'!
optionInstances
	^ Array with: 'foo' with: 'bar' with: 'zork'.! !

!MAOptionDescriptionTest methodsFor: 'running' stamp: 'lr 9/15/2005 11:35'!
setUp
	super setUp.
	self description options: self optionInstances.! !

!MAOptionDescriptionTest methodsFor: 'testing-accessing' stamp: 'lr 11/14/2005 08:24'!
testAllOptions
	self description beRequired; beSorted; options: #( c b a ).
	self assert: self description allOptions = #( a b c ).
	
	self description beRequired; beUnsorted; options: #( c b a ).
	self assert: self description allOptions = #( c b a ).! !

!MAOptionDescriptionTest methodsFor: 'testing-accessing' stamp: 'lr 11/14/2005 08:26'!
testAllOptionsWith
	self description beRequired; beSorted; options: #( c d a ).
	self assert: (self description allOptionsWith: #b) = #( a b c d ).
	
	self description beRequired; beUnsorted; options: #( c d a ).
	self assert: (self description allOptionsWith: #b) = #( c d a b ).! !

!MAOptionDescriptionTest methodsFor: 'testing-accessing' stamp: 'lr 11/15/2005 19:41'!
testAllOptionsWithExisting
	self description beRequired; options: #( a b c ).
	self assert: (self description allOptionsWith: #a) = #( a b c ).! !

!MAOptionDescriptionTest methodsFor: 'testing-accessing' stamp: 'lr 11/15/2005 19:41'!
testAllOptionsWithNil
	self description beRequired; options: #( a b c ).
	self assert: (self description allOptionsWith: nil) = #( a b c ).! !

!MAOptionDescriptionTest methodsFor: 'testing-copying' stamp: 'lr 9/15/2005 11:34'!
testCopyOptions
	self deny: self description copy options == self description options.
	self assert: self description copy options = self description options.! !

!MAOptionDescriptionTest methodsFor: 'testing-accessing' stamp: 'lr 9/15/2005 11:33'!
testOptions
	self description options: #( a b c ).
	self assert: self description options = #( a b c ).! !

!MAOptionDescriptionTest methodsFor: 'testing-properties' stamp: 'lr 9/15/2005 11:37'!
testSorted
	self description beSorted.
	self assert: self description isSorted.
	self assert: self description sorted.
	
	self description beUnsorted.
	self deny: self description isSorted.
	self deny: self description sorted.! !

MAOptionDescriptionTest subclass: #MASingleOptionDescriptionTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Magritte-Tests-Description'!

!MASingleOptionDescriptionTest class methodsFor: 'testing' stamp: 'lr 12/5/2005 20:58'!
isAbstract
	^ false! !

!MASingleOptionDescriptionTest methodsFor: 'private' stamp: 'lr 12/5/2005 20:58'!
actualClass
	^ MASingleOptionDescription! !

!MASingleOptionDescriptionTest methodsFor: 'private' stamp: 'lr 9/26/2005 09:13'!
includedInstance
	^ self optionInstances first.! !

!MASingleOptionDescriptionTest methodsFor: 'testing-accessing' stamp: 'lr 11/14/2005 08:28'!
testAllOptionsOptional
	self description beOptional; beSorted; options: #( c b a ).
	self assert: self description allOptions = #( nil a b c ).
	
	self description beOptional; beUnsorted; options: #( c b a ).
	self assert: self description allOptions = #( nil c b a ).! !

!MASingleOptionDescriptionTest methodsFor: 'testing-accessing' stamp: 'lr 11/14/2005 08:29'!
testAllOptionsWithOptional
	self description beOptional; beSorted; options: #( c d a ).
	self assert: (self description allOptionsWith: #b) = #( nil a b c d ).
	
	self description beOptional; beUnsorted; options: #( c d a ).
	self assert: (self description allOptionsWith: #b) = #( nil c d a b ).! !

!MASingleOptionDescriptionTest methodsFor: 'testing-properties' stamp: 'lr 11/11/2005 16:39'!
testExtensible
	self description beExtensible.
	self assert: self description isExtensible.
	self assert: self description extensible.
	
	self description beLimited.
	self deny: self description isExtensible.
	self deny: self description extensible.! !

!MASingleOptionDescriptionTest methodsFor: 'private' stamp: 'lr 11/11/2005 16:37'!
testSorted
	self description beSorted.
	self assert: self description isSorted.
	self assert: self description sorted.
	
	self description beUnsorted.
	self deny: self description isSorted.
	self deny: self description sorted.! !

!MAReferenceDescriptionTest class methodsFor: 'testing' stamp: 'lr 12/5/2005 20:58'!
isAbstract
	^ true! !

!MAReferenceDescriptionTest methodsFor: 'private' stamp: 'lr 12/5/2005 20:58'!
actualClass
	^ MAReferenceDescription! !

!MAReferenceDescriptionTest methodsFor: 'private' stamp: 'lr 11/7/2005 18:05'!
referenceInstance
	^ MAStringDescription null.! !

!MAReferenceDescriptionTest methodsFor: 'running' stamp: 'lr 9/15/2005 11:49'!
setUp
	super setUp.
	self description reference: self referenceInstance.! !

!MAReferenceDescriptionTest methodsFor: 'testing-copying' stamp: 'lr 9/26/2005 09:20'!
testCopyReference
	self assert: self description copy reference = self description reference.
	self deny: self description copy reference == self description reference.! !

MAReferenceDescriptionTest subclass: #MARelationDescriptionTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Magritte-Tests-Description'!

MARelationDescriptionTest subclass: #MAOneToManyRelationDescriptionTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Magritte-Tests-Description'!

!MAOneToManyRelationDescriptionTest class methodsFor: 'testing' stamp: 'lr 12/5/2005 20:58'!
isAbstract
	^ false! !

!MAOneToManyRelationDescriptionTest methodsFor: 'private' stamp: 'lr 12/5/2005 20:58'!
actualClass
	^ MAOneToManyRelationDescription! !

!MAOneToManyRelationDescriptionTest methodsFor: 'private' stamp: 'lr 10/27/2005 17:35'!
includedInstance
	^ Array with: self addressInstance1 with: self addressInstance2.! !

MARelationDescriptionTest subclass: #MAOneToOneRelationDescriptionTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Magritte-Tests-Description'!

!MAOneToOneRelationDescriptionTest class methodsFor: 'testing' stamp: 'lr 12/5/2005 20:58'!
isAbstract
	^ false! !

!MAOneToOneRelationDescriptionTest methodsFor: 'private' stamp: 'lr 12/5/2005 20:58'!
actualClass
	^ MAOneToOneRelationDescription! !

!MAOneToOneRelationDescriptionTest methodsFor: 'private' stamp: 'lr 10/27/2005 17:35'!
includedInstance
	^ self addressInstance1.! !

!MARelationDescriptionTest class methodsFor: 'testing' stamp: 'lr 12/5/2005 20:58'!
isAbstract
	^ true! !

!MARelationDescriptionTest methodsFor: 'private' stamp: 'lr 12/5/2005 20:58'!
actualClass
	^ MARelationDescription! !

!MARelationDescriptionTest methodsFor: 'private' stamp: 'lr 1/18/2006 16:21'!
addressInstance1
	^ MAMockAddress new
		street: 'Philosophenweg 5';
		plz: 3007; place: 'Bern';
		yourself.! !

!MARelationDescriptionTest methodsFor: 'private' stamp: 'lr 1/18/2006 16:22'!
addressInstance2
	^ MAMockAddress new
		street: 'In der Au';
		plz: 8765; place: 'Engi';
		yourself.! !

!MARelationDescriptionTest methodsFor: 'running' stamp: 'lr 1/18/2006 16:27'!
setUp
	super setUp.
	self description classes: (Array with: MAMockAddress).! !

!MARelationDescriptionTest methodsFor: 'private' stamp: 'lr 11/13/2005 11:38'!
shouldSkipStringTests
	^ true! !

!MARelationDescriptionTest methodsFor: 'testing-copying' stamp: 'lr 10/27/2005 16:58'!
testCopyClasses
	self assert: self description copy classes = self description classes.
	self deny: self description copy classes == self description classes.! !

MAReferenceDescriptionTest subclass: #MATableDescriptionTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Magritte-Tests-Description'!

!MATableDescriptionTest class methodsFor: 'testing' stamp: 'lr 12/5/2005 20:58'!
isAbstract
	^ false! !

!MATableDescriptionTest methodsFor: 'private' stamp: 'lr 12/5/2005 20:58'!
actualClass
	^ MATableDescription! !

!MATableDescriptionTest methodsFor: 'private' stamp: 'lr 10/10/2005 09:43'!
includedInstance
	^ MATableModel rows: 3 columns: 3 contents: #( '1' '2' '3' '2' '4' '6' '3' '6' '9' ). ! !

!MATableDescriptionTest methodsFor: 'private' stamp: 'lr 11/13/2005 11:38'!
shouldSkipStringTests
	^ true! !

MAReferenceDescriptionTest subclass: #MATokenDescriptionTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Magritte-Tests-Description'!

!MATokenDescriptionTest class methodsFor: 'testing' stamp: 'lr 12/5/2005 20:58'!
isAbstract
	^ false! !

!MATokenDescriptionTest methodsFor: 'private' stamp: 'lr 12/5/2005 20:58'!
actualClass
	^ MATokenDescription! !

!MATokenDescriptionTest methodsFor: 'private' stamp: 'lr 9/15/2005 11:28'!
includedInstance
	^ #( 'foo' 'bar' )! !

MAElementDescriptionTest subclass: #MAStringDescriptionTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Magritte-Tests-Description'!

MAStringDescriptionTest subclass: #MAMemoDescriptionTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Magritte-Tests-Description'!

!MAMemoDescriptionTest methodsFor: 'private' stamp: 'lr 1/18/2006 15:00'!
actualClass
	^ MAMemoDescription! !

!MAMemoDescriptionTest methodsFor: 'testing-properties' stamp: 'lr 1/18/2006 15:00'!
testLineCount
	self description lineCount: 123.
	self assert: self description lineCount = 123.! !

MAStringDescriptionTest subclass: #MAPasswordDescriptionTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Magritte-Tests-Description'!

!MAPasswordDescriptionTest class methodsFor: 'testing' stamp: 'lr 12/5/2005 20:58'!
isAbstract
	^ false! !

!MAPasswordDescriptionTest methodsFor: 'private' stamp: 'lr 12/5/2005 20:58'!
actualClass
	^ MAPasswordDescription! !

!MAStringDescriptionTest class methodsFor: 'testing' stamp: 'lr 12/5/2005 20:58'!
isAbstract
	^ false! !

!MAStringDescriptionTest methodsFor: 'private' stamp: 'lr 12/5/2005 20:58'!
actualClass
	^ MAStringDescription! !

!MAStringDescriptionTest methodsFor: 'private' stamp: 'lr 5/8/2005 20:32'!
includedInstance
	^ 'Lukas Renggli'! !

MAStringDescriptionTest subclass: #MASymbolDescriptionTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Magritte-Tests-Description'!

!MASymbolDescriptionTest class methodsFor: 'testing' stamp: 'lr 12/5/2005 20:58'!
isAbstract
	^ false! !

!MASymbolDescriptionTest methodsFor: 'private' stamp: 'lr 12/5/2005 20:58'!
actualClass
	^ MASymbolDescription! !

!MASymbolDescriptionTest methodsFor: 'private' stamp: 'lr 5/8/2005 20:32'!
includedInstance
	^ #magritte! !

MAObjectTest subclass: #MAMementoTest
	instanceVariableNames: 'description memento value'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Magritte-Tests-Memento'!

MAMementoTest subclass: #MACachedMementoTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Magritte-Tests-Memento'!

!MACachedMementoTest class methodsFor: 'testing' stamp: 'lr 12/5/2005 20:58'!
isAbstract
	^ false! !

!MACachedMementoTest methodsFor: 'private' stamp: 'lr 12/5/2005 20:58'!
actualClass
	^ MACachedMemento! !

!MACachedMementoTest methodsFor: 'testing-accessing' stamp: 'lr 9/20/2005 23:07'!
testCache
	self assert: self memento cache size = self description size.! !

!MACachedMementoTest methodsFor: 'testing-actions' stamp: 'lr 9/20/2005 22:08'!
testCommit
	self write: self includedInstance.
	self assert: self read = self includedInstance.
	self assert: self value = self nullInstance.
	self assert: self memento hasChanged.
	
	self memento commit.
	self assert: self read = self includedInstance.
	self assert: self value = self includedInstance.
	self deny: self memento hasChanged.! !

!MACachedMementoTest methodsFor: 'testing-basic' stamp: 'lr 9/20/2005 23:00'!
testRead
	self assert: self read = self defaultInstance.
	
	self value: self includedInstance.
	self assert: self read = self defaultInstance.! !

!MACachedMementoTest methodsFor: 'testing-actions' stamp: 'lr 9/20/2005 23:11'!
testReset
	self value: self defaultInstance.
	self write: self includedInstance.
	self assert: self memento hasChanged.
	
	self memento reset.
	self assert: self read = self defaultInstance.
	self assert: self value = self defaultInstance.
	self deny: self memento hasChanged.! !

!MACachedMementoTest methodsFor: 'testing-basic' stamp: 'lr 11/7/2005 18:55'!
testWrite
	self write: self includedInstance.
	self assert: self read = self includedInstance.
	self assert: self value = self nullInstance.
	
	self write: self defaultInstance.
	self assert: self read = self defaultInstance.
	self assert: self value = self nullInstance.
! !

MACachedMementoTest subclass: #MACheckedMementoTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Magritte-Tests-Memento'!

!MACheckedMementoTest class methodsFor: 'testing' stamp: 'lr 12/5/2005 20:58'!
isAbstract
	^ false! !

!MACheckedMementoTest methodsFor: 'private' stamp: 'lr 12/5/2005 20:58'!
actualClass
	^ MACheckedMemento! !

!MACheckedMementoTest methodsFor: 'testing-actions' stamp: 'lr 9/21/2005 07:26'!
testConflictCommit
	self write: self includedInstance.
	self assert: self read = self includedInstance.
	self assert: self memento hasChanged.
	self deny: self memento hasConflict.
	
	self value: self otherInstance.
	self assert: self read = self includedInstance.
	self assert: self memento hasChanged.
	self assert: self memento hasConflict.
	
	self memento commit.
	self assert: self read = self includedInstance.
	self assert: self value = self includedInstance.
	self deny: self memento hasChanged.
	self deny: self memento hasConflict.! !

!MACheckedMementoTest methodsFor: 'testing-actions' stamp: 'lr 9/21/2005 07:27'!
testConflictReset
	self write: self includedInstance.
	self assert: self read = self includedInstance.
	self assert: self memento hasChanged.
	self deny: self memento hasConflict.
	
	self value: self otherInstance.
	self assert: self read = self includedInstance.
	self assert: self memento hasChanged.
	self assert: self memento hasConflict.
	
	self memento reset.
	self assert: self read = self otherInstance.
	self assert: self value = self otherInstance.
	self deny: self memento hasChanged.
	self deny: self memento hasConflict.! !

!MACheckedMementoTest methodsFor: 'testing-accessing' stamp: 'lr 9/20/2005 23:07'!
testOriginal
	self assert: self memento original size = self description size.! !

!MACheckedMementoTest methodsFor: 'testing-actions' stamp: 'lr 9/21/2005 07:26'!
testValidateConflictCommit
	self write: self includedInstance.
	self shouldnt: [ self memento validate ] raise: MAValidationError.
	
	self value: self otherInstance.
	self should: [ self memento validate ] raise: MAValidationError.
	
	self memento commit.
	self shouldnt: [ self memento validate ] raise: MAValidationError.! !

!MACheckedMementoTest methodsFor: 'testing-actions' stamp: 'lr 9/21/2005 07:26'!
testValidateConflictReset
	self write: self includedInstance.
	self shouldnt: [ self memento validate ] raise: MAValidationError.
	
	self value: self otherInstance.
	self should: [ self memento validate ] raise: MAValidationError.
	
	self memento reset.
	self shouldnt: [ self memento validate ] raise: MAValidationError.! !

!MAMementoTest class methodsFor: 'testing' stamp: 'lr 12/5/2005 20:58'!
isAbstract
	^ true! !

!MAMementoTest methodsFor: 'private' stamp: 'lr 12/5/2005 20:58'!
actualClass
	^ MAMemento! !

!MAMementoTest methodsFor: 'private' stamp: 'lr 9/20/2005 22:51'!
defaultInstance
	^ 'Lukas Renggli'! !

!MAMementoTest methodsFor: 'accessing' stamp: 'lr 9/20/2005 21:24'!
description
	^ description! !

!MAMementoTest methodsFor: 'private' stamp: 'lr 9/20/2005 22:51'!
descriptionInstance
	^ MAContainer with: ((MAStringDescription selector: #value)
		default: self defaultInstance;
		yourself).! !

!MAMementoTest methodsFor: 'accessing' stamp: 'lr 9/20/2005 23:05'!
descriptionValue
	^ self description children first.! !

!MAMementoTest methodsFor: 'private' stamp: 'lr 9/20/2005 23:43'!
includedInstance
	^ 'Rene Magritte'! !

!MAMementoTest methodsFor: 'accessing' stamp: 'lr 5/8/2005 20:31'!
instance
	^ memento! !

!MAMementoTest methodsFor: 'private' stamp: 'lr 5/8/2005 20:31'!
invalidInstance
	^ 31415! !

!MAMementoTest methodsFor: 'accessing' stamp: 'lr 9/20/2005 21:24'!
memento
	^ memento! !

!MAMementoTest methodsFor: 'private' stamp: 'lr 12/21/2005 20:24'!
mementoInstance
	^ self actualClass model: self modelInstance.! !

!MAMementoTest methodsFor: 'private' stamp: 'lr 9/20/2005 21:03'!
modelInstance 
	^ self! !

!MAMementoTest methodsFor: 'private' stamp: 'lr 9/20/2005 22:02'!
nullInstance
	^ nil! !

!MAMementoTest methodsFor: 'private' stamp: 'lr 9/20/2005 23:43'!
otherInstance
	^ 'Ursula Freitag'! !

!MAMementoTest methodsFor: 'accessing-memento' stamp: 'lr 9/20/2005 23:06'!
read
	^ self memento readUsing: self descriptionValue.! !

!MAMementoTest methodsFor: 'running' stamp: 'lr 9/20/2005 21:23'!
setUp
	super setUp.
	description := self descriptionInstance.
	memento := self mementoInstance.! !

!MAMementoTest methodsFor: 'testing-actions' stamp: 'lr 9/20/2005 23:08'!
testCommit
	self subclassResponsibility.! !

!MAMementoTest methodsFor: 'testing-accessing' stamp: 'lr 9/20/2005 21:27'!
testDescription
	self assert: self memento description = self description.
	self assert: self memento description = self descriptionInstance.! !

!MAMementoTest methodsFor: 'testing-accessing' stamp: 'lr 9/20/2005 21:17'!
testModel
	self assert: self memento model = self modelInstance.! !

!MAMementoTest methodsFor: 'testing-basic' stamp: 'lr 9/20/2005 22:59'!
testRead
	self subclassResponsibility.! !

!MAMementoTest methodsFor: 'testing-actions' stamp: 'lr 9/20/2005 23:08'!
testReset
	self subclassResponsibility.! !

!MAMementoTest methodsFor: 'testing-actions' stamp: 'lr 9/21/2005 07:28'!
testValidateIncluded
	self write: self includedInstance.
	self shouldnt: [ self memento validate ] raise: MAValidationError.! !

!MAMementoTest methodsFor: 'testing-actions' stamp: 'lr 9/21/2005 07:28'!
testValidateInvalid
	self write: self invalidInstance.
	self should: [ self memento validate ] raise: MAValidationError.! !

!MAMementoTest methodsFor: 'testing-actions' stamp: 'lr 9/21/2005 07:28'!
testValidateRequired
	self descriptionValue beRequired.
	
	self write: self nullInstance.
	self should: [ self memento validate ] raise: MAValidationError.! !

!MAMementoTest methodsFor: 'testing-basic' stamp: 'lr 9/20/2005 22:59'!
testWrite
	self subclassResponsibility.! !

!MAMementoTest methodsFor: 'accessing-model' stamp: 'lr 5/8/2005 20:31'!
value
	^ value! !

!MAMementoTest methodsFor: 'accessing-model' stamp: 'lr 5/8/2005 20:31'!
value: anObject
	value := anObject! !

!MAMementoTest methodsFor: 'accessing-memento' stamp: 'lr 9/20/2005 23:06'!
write: anObject
	self memento write: anObject using: self descriptionValue.! !

MAMementoTest subclass: #MAStraitMementoTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Magritte-Tests-Memento'!

!MAStraitMementoTest class methodsFor: 'testing' stamp: 'lr 12/5/2005 20:58'!
isAbstract
	^ false! !

!MAStraitMementoTest methodsFor: 'private' stamp: 'lr 12/5/2005 20:58'!
actualClass
	^ MAStraitMemento! !

!MAStraitMementoTest methodsFor: 'testing-actions' stamp: 'lr 9/20/2005 23:20'!
testCommit
	self write: self includedInstance.
	self assert: self value = self includedInstance.
	self assert: self read = self includedInstance.
	
	self memento commit.
	self assert: self value = self includedInstance.
	self assert: self read = self includedInstance.
! !

!MAStraitMementoTest methodsFor: 'testing-basic' stamp: 'lr 9/20/2005 22:54'!
testRead
	self assert: self read = self defaultInstance.
	
	self value: self includedInstance.
	self assert: self read = self includedInstance.
	
	self value: self defaultInstance.
	self assert: self read = self defaultInstance.! !

!MAStraitMementoTest methodsFor: 'testing-actions' stamp: 'lr 9/20/2005 23:19'!
testReset
	self write: self includedInstance.
	self memento reset.
	self assert: self read = self includedInstance.! !

!MAStraitMementoTest methodsFor: 'testing-actions' stamp: 'lr 9/20/2005 23:52'!
testValidateRequired! !

!MAStraitMementoTest methodsFor: 'testing-basic' stamp: 'lr 9/20/2005 22:59'!
testWrite
	self write: self includedInstance.
	self assert: self value = self includedInstance.
	
	self write: self defaultInstance.
	self assert: self value = self defaultInstance.
	
	self write: self nullInstance.
	self assert: self value = self nullInstance.! !

!MAObjectTest class methodsFor: 'building' stamp: 'lr 12/5/2005 20:58'!
buildTestClassFor: aClass 
	" self buildTestClassFor: MAObject "

	| thisName thisClass thisCategory parentClass |
	thisName := (aClass name , 'Test') asSymbol.
	(thisName beginsWith: 'MA') 
		ifFalse: [ ^ self ].
	thisClass := MACompatibility classNamed: thisName.
	thisCategory := 'Magritte-Tests-' , (aClass category copyAfterLast: $-).
	parentClass := self = thisClass 
		ifTrue: [ self superclass ]
		ifFalse: [ Smalltalk classNamed: (aClass superclass name , 'Test') asSymbol ].
	thisClass := parentClass 
		subclass: thisName
		instanceVariableNames: (thisClass isNil 
			ifFalse: [ thisClass instanceVariablesString ]
			ifTrue: [ String new ])
			classVariableNames: ''
			poolDictionaries: ''
			category: thisCategory.
	thisClass 
		compile: 'actualClass
	^ ' , aClass name 
		classified: #private.
	thisClass class 
		compile: 'isAbstract
	^ ' , aClass isAbstract asString
		classified: #testing.
	aClass subclassesDo: [ :each | self buildTestClassFor: each ].! !

!MAObjectTest class methodsFor: 'testing' stamp: 'lr 12/5/2005 20:58'!
isAbstract
	^ true! !

!MAObjectTest class methodsFor: 'testing' stamp: 'lr 9/23/2005 19:32'!
shouldInheritSelectors
	^ true! !

!MAObjectTest methodsFor: 'private' stamp: 'lr 12/5/2005 20:58'!
actualClass
	^ MAObject! !

!MAObjectTest methodsFor: 'accessing' stamp: 'lr 5/8/2005 20:31'!
instance
	self subclassResponsibility.! !

!MAObjectTest methodsFor: 'testing-copying' stamp: 'lr 9/23/2005 20:24'!
testCopy
	self assert: self instance = self instance copy.
	self deny: self instance == self instance copy.! !

!MAObjectTest methodsFor: 'testing-copying' stamp: 'lr 9/23/2005 20:24'!
testCopyProperties
	self assert: self instance properties = self instance copy properties.
	self deny: self instance properties == self instance copy properties.! !

!MAObjectTest methodsFor: 'testing-comparing' stamp: 'lr 9/15/2005 10:20'!
testEqual
	self assert: self instance = self instance.
	self assert: self instance = self instance copy.
	self assert: self instance copy = self instance.
	
	self deny: self instance = 123.
	self deny: self instance = String new.! !

!MAObjectTest methodsFor: 'testing-comparing' stamp: 'lr 9/15/2005 10:21'!
testHash
	self assert: self instance hash isInteger.
	self assert: self instance hash = self instance hash.
	self assert: self instance hash = self instance copy hash.! !

!MAObjectTest methodsFor: 'testing-testing' stamp: 'lr 12/16/2005 18:29'!
testIsAccessor
	self deny: self instance isAccessor.! !

!MAObjectTest methodsFor: 'testing-testing' stamp: 'lr 1/18/2006 09:38'!
testIsCondition
	self deny: self instance isCondition.! !

!MAObjectTest methodsFor: 'testing-testing' stamp: 'lr 12/16/2005 18:28'!
testIsDescription
	self deny: self instance isDescription.! !

!MAObjectTest methodsFor: 'testing-properties' stamp: 'lr 9/15/2005 10:28'!
testProperties
	self assert: self instance properties notNil.
	self instance instVarNamed: 'properties' put: nil.
	
	self instance propertyAt: #foo put: #bar.
	self instance instVarNamed: 'properties' put: nil.

	self instance propertyAt: #foo ifAbsent: [ nil ].
	self instance instVarNamed: 'properties' put: nil.

	self instance propertyAt: #foo ifAbsentPut: [ #bar ].
	self instance instVarNamed: 'properties' put: nil.
	
	self instance hasProperty: #foo.
	self instance instVarNamed: 'properties' put: nil.! !

!MAObjectTest methodsFor: 'testing-properties' stamp: 'lr 5/8/2005 20:31'!
testPropertiesAt
	self assert: (self instance propertyAt: #foo put: 'bar') = 'bar'.
	self assert: (self instance propertyAt: #foo) = 'bar'.
	self should: [ self instance propertyAt: #bar ] raise: Error.! !

!MAObjectTest methodsFor: 'testing-properties' stamp: 'lr 5/8/2005 20:31'!
testPropertiesAtIfAbsent
	self assert: (self instance propertyAt: #foo put: 'bar') = 'bar'.
	self assert: (self instance propertyAt: #foo ifAbsent: [ 'baz' ]) = 'bar'.
	self assert: (self instance propertyAt: #bar ifAbsent: [ 'baz' ]) = 'baz'.! !

!MAObjectTest methodsFor: 'testing-properties' stamp: 'lr 5/8/2005 20:31'!
testPropertiesAtIfAbsentPut
	self assert: (self instance propertyAt: #foo put: 'bar') = 'bar'.
	self assert: (self instance propertyAt: #foo ifAbsentPut: [ 'baz' ]) = 'bar'.
	self assert: (self instance propertyAt: #foo) = 'bar'.
	
	self assert: (self instance propertyAt: #bar ifAbsentPut: [ 'baz' ]) = 'baz'.
	self assert: (self instance propertyAt: #bar) = 'baz'.! !

!MAObjectTest methodsFor: 'testing-properties' stamp: 'lr 5/8/2005 20:31'!
testPropertiesAtPut
	self instance propertyAt: #foo put: 'bar'.
	self assert: (self instance propertyAt: #foo) = 'bar'.
	
	self instance propertyAt: #foo put: 'baz'.
	self assert: (self instance propertyAt: #foo) = 'baz'.! !

!MAObjectTest methodsFor: 'testing-properties' stamp: 'lr 7/7/2005 14:50'!
testPropertiesHas
	self deny: (self instance hasProperty: #foo).
	self instance propertyAt: #foo put: 'bar'.
	self assert: (self instance hasProperty: #foo).
	self deny: (self instance hasProperty: #bar).! !

!MAObjectTest methodsFor: 'testing-identity' stamp: 'lr 10/13/2005 18:41'!
testReferenceStream
	" This is an unfortunately non-portable test-method: the idea of this test is that every object should be serializeable and after restoring it, the objects should be still equal. "

	| output input object |
	
	" every instance should be serializeable "
	output := MACompatibility referenceStream: ByteArray new writeStream.
	output nextPut: self instance.
	output close.
	
	" read back the serialized instance "
	input := MACompatibility referenceStream: output contents readStream.
	object := input next.
	
	" different object reference, but equal object "
	self deny: self instance == object.
	self assert: self instance = object.
	
	" return the read in object (for addinal checks in subclasses) "
	^ object.! !

!MAObjectTest methodsFor: 'testing' stamp: 'lr 12/21/2005 20:25'!
testSanity
	"If this test case fails, there is something wrong with the setup of the test-case."

	self 
		assert: self actualClass isAbstract not
		description: 'Unable to test abstract class.'.
	self 
		assert: self instance class = self actualClass
		description: 'Invalid test instance.'.! !

TestCase subclass: #MAScaffolderTest
	instanceVariableNames: 'scaffolder'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Magritte-Tests-Model'!

!MAScaffolderTest methodsFor: 'accessing' stamp: 'lr 9/9/2005 11:27'!
descriptions
	^ self scaffolder description children.! !

!MAScaffolderTest methodsFor: 'accessing' stamp: 'lr 9/9/2005 11:25'!
scaffolder
	^ scaffolder! !

!MAScaffolderTest methodsFor: 'running' stamp: 'lr 11/7/2005 18:06'!
setUp
	scaffolder := MAScaffolder new.
	scaffolder description
		add: (MAStringDescription null);
		add: (MANumberDescription null).
	scaffolder write: 'foo' using: self descriptions first.
	scaffolder write: 123 using: self descriptions second.
	! !

!MAScaffolderTest methodsFor: 'testing' stamp: 'lr 9/9/2005 11:31'!
testRead
	self assert: (self scaffolder readUsing: self descriptions first) = 'foo'.
	self assert: (self scaffolder readUsing: self descriptions second) = 123.! !

!MAScaffolderTest methodsFor: 'testing' stamp: 'lr 9/9/2005 11:31'!
testWrite
	self scaffolder write: 'bar' using: self descriptions first.
	self scaffolder write: 321 using: self descriptions second.
	
	self assert: (self scaffolder readUsing: self descriptions first) = 'bar'.
	self assert: (self scaffolder readUsing: self descriptions second) = 321.! !

TestCase subclass: #MATableModelTest
	instanceVariableNames: 'table'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Magritte-Tests-Model'!

!MATableModelTest methodsFor: 'running' stamp: 'lr 10/3/2005 11:23'!
setUp
	table := (MATableModel rows: 3 columns: 4)
		collect: [ :row :col :value | row raisedTo: col ].! !

!MATableModelTest methodsFor: 'testing-accessing' stamp: 'lr 10/3/2005 11:26'!
testAtAt
	self assert: (table at: 1 at: 1) = 1.
	self assert: (table at: 2 at: 3) = 8.
	self assert: (table at: 3 at: 2) = 9.	
	self assert: (table at: 3 at: 4) = 81.


	! !

!MATableModelTest methodsFor: 'testing-accessing' stamp: 'lr 10/3/2005 11:26'!
testAtAtAbsent
	self should: [ table at: 0 at: 1 ] raise: Error.
	self should: [ table at: 1 at: 0 ] raise: Error.
	self should: [ table at: 4 at: 4 ] raise: Error.
	self should: [ table at: 3 at: 5 ] raise: Error.! !

!MATableModelTest methodsFor: 'testing-accessing' stamp: 'lr 10/3/2005 11:29'!
testAtAtPut
	self assert: (table at: 1 at: 1 put: -1) = -1.
	self assert: (table at: 2 at: 3 put: -8) = -8.
	self assert: (table at: 3 at: 2 put: -9) = -9.	
	self assert: (table at: 3 at: 4 put: -81) = -81.

	self assert: (table at: 1 at: 1) = -1.
	self assert: (table at: 2 at: 3) = -8.
	self assert: (table at: 3 at: 2) = -9.	
	self assert: (table at: 3 at: 4) = -81.! !

!MATableModelTest methodsFor: 'testing-accessing' stamp: 'lr 10/3/2005 11:28'!
testAtAtPutAbsent
	self should: [ table at: 0 at: 1 put: 0 ] raise: Error.
	self should: [ table at: 1 at: 0 put: 0 ] raise: Error.
	self should: [ table at: 4 at: 4 put: 0 ] raise: Error.
	self should: [ table at: 3 at: 5 put: 0 ] raise: Error.! !

!MATableModelTest methodsFor: 'testing-enumerating' stamp: 'lr 10/3/2005 11:48'!
testCollect
	table := table collect: [ :row :col :val | row + col + val ].
	table do: [ :row :col :val | self assert: (row raisedTo: col) = (val - row - col) ].! !

!MATableModelTest methodsFor: 'testing-accessing' stamp: 'lr 10/3/2005 11:29'!
testContents
	self assert: table contents = #( 1 1 1 1 2 4 8 16 3 9 27 81 ).! !

!MATableModelTest methodsFor: 'testing-copying' stamp: 'lr 10/3/2005 11:51'!
testCopy
	self assert: table copy rowCount = table rowCount.
	self assert: table copy columnCount = table columnCount.
	self assert: table copy contents = table contents.
	self deny: table copy contents == table contents.! !

!MATableModelTest methodsFor: 'testing-copying' stamp: 'lr 10/3/2005 11:50'!
testCopyEmpty
	self assert: table copyEmpty rowCount = table rowCount.
	self assert: table copyEmpty columnCount = table columnCount.
	self assert: (table copyEmpty contents allSatisfy: [ :each | each isNil ]).! !

!MATableModelTest methodsFor: 'testing-copying' stamp: 'lr 10/3/2005 11:53'!
testCopyRowsColumns
	self assert: (table copyRows: 1 columns: 2) rowCount = 1.
	self assert: (table copyRows: 1 columns: 2) columnCount = 2.
	self assert: (table copyRows: 1 columns: 2) contents = #(1 1).

	self assert: (table copyRows: 4 columns: 3) rowCount = 4.
	self assert: (table copyRows: 4 columns: 3) columnCount = 3.
	self assert: (table copyRows: 4 columns: 3) contents = #(1 1 1 2 4 8 3 9 27 nil nil nil).! !

!MATableModelTest methodsFor: 'testing-accessing' stamp: 'lr 10/3/2005 11:29'!
testCoumnCount
	self assert: table columnCount = 4.! !

!MATableModelTest methodsFor: 'testing-enumerating' stamp: 'lr 10/3/2005 11:48'!
testDo
	table do: [ :row :col :val | self assert: (row raisedTo: col) = val ].! !

!MATableModelTest methodsFor: 'testing-comparing' stamp: 'lr 10/3/2005 11:33'!
testEqual
	self assert: table = table.
	self assert: table = table copy.
	self assert: table copy = table.
	self assert: table copy = table copy.

	self deny: table = (table copy at: 1 at: 2 put: 3).
	self deny: table = (table copyRows: 3 columns: 3). 
	self deny: table = (table copyRows: 4 columns: 4). 
	! !

!MATableModelTest methodsFor: 'testing-comparing' stamp: 'lr 10/3/2005 11:32'!
testHash
	self assert: table hash = table hash.
	self assert: table hash = table copy hash.
	self assert: table copy hash = table hash.
	self assert: table copy hash = table copy hash.! !

!MATableModelTest methodsFor: 'testing-accessing' stamp: 'lr 10/3/2005 11:29'!
testRowCount
	self assert: table rowCount = 3.! !

!MATableModelTest methodsFor: 'testing' stamp: 'lr 10/3/2005 11:23'!
testSetup
	self assert: table rowCount = 3.
	self assert: table columnCount = 4.
	self assert: table contents = #( 1 1 1 1 2 4 8 16 3 9 27 81 ).! !

!TestCase methodsFor: '*magritte-tests' stamp: 'lr 12/28/2005 11:32'!
should: aBlock raise: anExceptionalEvent do: aOneArgumentBlock
	self assert: ([ aBlock value. false ]
		sunitOn: anExceptionalEvent
		do: [ :ex | 
			aOneArgumentBlock value: ex. 
			ex sunitExitWith: true ]).! !

Object subclass: #MAMockAddress
	instanceVariableNames: 'place street plz'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Magritte-Tests-Mock'!

!MAMockAddress class methodsFor: 'descriptions' stamp: 'lr 1/18/2006 16:24'!
descriptionPlace
	^ MAStringDescription auto: 'place'.! !

!MAMockAddress class methodsFor: 'descriptions' stamp: 'lr 1/18/2006 16:23'!
descriptionPlz
	^ MANumberDescription auto: 'plz'! !

!MAMockAddress class methodsFor: 'descriptions' stamp: 'lr 1/18/2006 16:23'!
descriptionStreet
	^ MAStringDescription auto: 'street'! !

!MAMockAddress methodsFor: 'comparing' stamp: 'lr 1/18/2006 16:25'!
hash
	^ self street hash.! !

!MAMockAddress methodsFor: 'accessing-generated' stamp: 'lr 1/18/2006 16:23'!
place
	^ place! !

!MAMockAddress methodsFor: 'accessing-generated' stamp: 'lr 1/18/2006 16:24'!
place: anObject
	place := anObject! !

!MAMockAddress methodsFor: 'accessing-generated' stamp: 'lr 1/18/2006 16:23'!
plz
	^ plz! !

!MAMockAddress methodsFor: 'accessing-generated' stamp: 'lr 1/18/2006 16:24'!
plz: anObject
	plz := anObject! !

!MAMockAddress methodsFor: 'accessing-generated' stamp: 'lr 1/18/2006 16:23'!
street
	^ street! !

!MAMockAddress methodsFor: 'accessing-generated' stamp: 'lr 1/18/2006 16:24'!
street: anObject
	street := anObject! !

!MAMockAddress methodsFor: 'comparing' stamp: 'lr 1/18/2006 16:27'!
= anObject
	^ self species = anObject species
		and: [ self street = anObject street ]
		and: [ self plz = anObject plz ]
		and: [ self place = anObject place ]
! !
